Class: Google::Apis::AlloydbV1alpha::AlloydbClhErrorsAlloyDbInternalDebugInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

AlloyDbInternalDebugInfo contains internal debugging information for AlloyDB errors. It is explicitly kept out of the allowlist (errors.yaml) to ensure it is sanitized (stripped) by OnePlatform for all external requests. Used only to carry internal error details to across UPC/FlowLib boundary for ObservabilityInfo.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlloydbClhErrorsAlloyDbInternalDebugInfo

Returns a new instance of AlloydbClhErrorsAlloyDbInternalDebugInfo.



39
40
41
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 39

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#original_errorString

The original error message or details before sanitization, used internally for debugging and logging. Corresponds to the JSON property originalError

Returns:

  • (String)


37
38
39
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 37

def original_error
  @original_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44
45
46
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 44

def update!(**args)
  @original_error = args[:original_error] if args.key?(:original_error)
end