Class: Google::Apis::AlloydbV1alpha::BackupDrEnabledWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Information about a single window when BackupDR was enabled for this cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupDrEnabledWindow

Returns a new instance of BackupDrEnabledWindow.



427
428
429
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automated_backup_previously_enabledBoolean Also known as: automated_backup_previously_enabled?

Whether automated backup was previously enabled prior to enabling BackupDR protection for this cluster. Corresponds to the JSON property automatedBackupPreviouslyEnabled

Returns:

  • (Boolean)


378
379
380
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 378

def automated_backup_previously_enabled
  @automated_backup_previously_enabled
end

#backup_plan_associationString

The BackupPlanAssociation resource that was used to enable BackupDR protection for this cluster. Corresponds to the JSON property backupPlanAssociation

Returns:

  • (String)


385
386
387
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 385

def backup_plan_association
  @backup_plan_association
end

#continuous_backup_previous_recovery_window_daysFixnum

The retention set for the continuous backup that was previously enabled prior to enabling BackupDR protection for this cluster. Corresponds to the JSON property continuousBackupPreviousRecoveryWindowDays

Returns:

  • (Fixnum)


391
392
393
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 391

def continuous_backup_previous_recovery_window_days
  @continuous_backup_previous_recovery_window_days
end

#continuous_backup_previously_enabledBoolean Also known as: continuous_backup_previously_enabled?

Whether continuous backup was previously enabled prior to enabling BackupDR protection for this cluster. Corresponds to the JSON property continuousBackupPreviouslyEnabled

Returns:

  • (Boolean)


397
398
399
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 397

def continuous_backup_previously_enabled
  @continuous_backup_previously_enabled
end

#continuous_backup_previously_enabled_timeString

The time when continuous backup was previously enabled prior to enabling BackupDR protection for this cluster. Corresponds to the JSON property continuousBackupPreviouslyEnabledTime

Returns:

  • (String)


404
405
406
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 404

def continuous_backup_previously_enabled_time
  @continuous_backup_previously_enabled_time
end

#data_sourceString

The DataSource resource that represents the cluster in BackupDR. Corresponds to the JSON property dataSource

Returns:

  • (String)


409
410
411
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 409

def data_source
  @data_source
end

#disabled_timeString

Time when the BackupDR protection for this cluster was disabled. This field will be empty if this BackupDR window is the current_window. Corresponds to the JSON property disabledTime

Returns:

  • (String)


415
416
417
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 415

def disabled_time
  @disabled_time
end

#enabled_timeString

Time when the BackupDR protection for this cluster was enabled. Corresponds to the JSON property enabledTime

Returns:

  • (String)


420
421
422
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 420

def enabled_time
  @enabled_time
end

#log_retention_periodString

The retention period for logs generated by BackupDR for this cluster. Corresponds to the JSON property logRetentionPeriod

Returns:

  • (String)


425
426
427
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 425

def log_retention_period
  @log_retention_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



432
433
434
435
436
437
438
439
440
441
442
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 432

def update!(**args)
  @automated_backup_previously_enabled = args[:automated_backup_previously_enabled] if args.key?(:automated_backup_previously_enabled)
  @backup_plan_association = args[:backup_plan_association] if args.key?(:backup_plan_association)
  @continuous_backup_previous_recovery_window_days = args[:continuous_backup_previous_recovery_window_days] if args.key?(:continuous_backup_previous_recovery_window_days)
  @continuous_backup_previously_enabled = args[:continuous_backup_previously_enabled] if args.key?(:continuous_backup_previously_enabled)
  @continuous_backup_previously_enabled_time = args[:continuous_backup_previously_enabled_time] if args.key?(:continuous_backup_previously_enabled_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @disabled_time = args[:disabled_time] if args.key?(:disabled_time)
  @enabled_time = args[:enabled_time] if args.key?(:enabled_time)
  @log_retention_period = args[:log_retention_period] if args.key?(:log_retention_period)
end