Class: Google::Apis::AlloydbV1alpha::BackupDrInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Information about BackupDR protection for this cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupDrInfo

Returns a new instance of BackupDrInfo.



463
464
465
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_windowGoogle::Apis::AlloydbV1alpha::BackupDrEnabledWindow

Information about a single window when BackupDR was enabled for this cluster. Corresponds to the JSON property currentWindow



452
453
454
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 452

def current_window
  @current_window
end

#previous_windowsArray<Google::Apis::AlloydbV1alpha::BackupDrEnabledWindow>

Windows during which BackupDR was enabled for this cluster, along with associated configuration for that window. These are used to determine points- in-time for which restores can be performed. The windows are ordered with the most recent window last. Windows are mutally exclusive. Windows which closed more than 1 year ago will be removed from this list. Corresponds to the JSON property previousWindows



461
462
463
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 461

def previous_windows
  @previous_windows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



468
469
470
471
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 468

def update!(**args)
  @current_window = args[:current_window] if args.key?(:current_window)
  @previous_windows = args[:previous_windows] if args.key?(:previous_windows)
end