Class: Google::Apis::AlloydbV1alpha::ConnectionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

ConnectionInfo singleton resource. https://google.aip.dev/156

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionInfo

Returns a new instance of ConnectionInfo.



1050
1051
1052
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_uidString

Output only. The unique ID of the Instance. Corresponds to the JSON property instanceUid

Returns:

  • (String)


1010
1011
1012
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1010

def instance_uid
  @instance_uid
end

#ip_addressString

Output only. The private network IP address for the Instance. This is the default IP for the instance and is always created (even if enable_public_ip is set). This is the connection endpoint for an end-user application. Corresponds to the JSON property ipAddress

Returns:

  • (String)


1017
1018
1019
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1017

def ip_address
  @ip_address
end

#nameString

The name of the ConnectionInfo singleton resource, e.g.: projects/project/ locations/location/clusters//instances//connectionInfo This field currently has no semantic meaning. Corresponds to the JSON property name

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1024

def name
  @name
end

#pem_certificate_chainArray<String>

Output only. The pem-encoded chain that may be used to verify the X.509 certificate. Expected to be in issuer-to-root order according to RFC 5246. Corresponds to the JSON property pemCertificateChain

Returns:

  • (Array<String>)


1030
1031
1032
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1030

def pem_certificate_chain
  @pem_certificate_chain
end

#psc_auto_dns_nameString

Output only. Specifies the DNS name to use with PSC service automation for the Instance. Corresponds to the JSON property pscAutoDnsName

Returns:

  • (String)


1036
1037
1038
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1036

def psc_auto_dns_name
  @psc_auto_dns_name
end

#psc_dns_nameString

Output only. The DNS name to use with PSC for the Instance. Corresponds to the JSON property pscDnsName

Returns:

  • (String)


1041
1042
1043
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1041

def psc_dns_name
  @psc_dns_name
end

#public_ip_addressString

Output only. The public IP addresses for the Instance. This is available ONLY when enable_public_ip is set. This is the connection endpoint for an end-user application. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


1048
1049
1050
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1048

def public_ip_address
  @public_ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1055
1056
1057
1058
1059
1060
1061
1062
1063
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1055

def update!(**args)
  @instance_uid = args[:instance_uid] if args.key?(:instance_uid)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @name = args[:name] if args.key?(:name)
  @pem_certificate_chain = args[:pem_certificate_chain] if args.key?(:pem_certificate_chain)
  @psc_auto_dns_name = args[:psc_auto_dns_name] if args.key?(:psc_auto_dns_name)
  @psc_dns_name = args[:psc_dns_name] if args.key?(:psc_dns_name)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
end