Class: Google::Apis::AlloydbV1alpha::CsvExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Options for exporting data in CSV format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CsvExportOptions

Returns a new instance of CsvExportOptions.



1274
1275
1276
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#escape_characterString

Optional. Specifies the character that should appear before a data character that needs to be escaped. The default is the same as quote character. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property escapeCharacter

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1253

def escape_character
  @escape_character
end

#field_delimiterString

Optional. Specifies the character that separates columns within each row (line) of the file. The default is comma. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property fieldDelimiter

Returns:

  • (String)


1260
1261
1262
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1260

def field_delimiter
  @field_delimiter
end

#quote_characterString

Optional. Specifies the quoting character to be used when a data value is quoted. The default is double-quote. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property quoteCharacter

Returns:

  • (String)


1267
1268
1269
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1267

def quote_character
  @quote_character
end

#select_queryString

Required. The SELECT query used to extract the data. Corresponds to the JSON property selectQuery

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1272

def select_query
  @select_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1279
1280
1281
1282
1283
1284
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1279

def update!(**args)
  @escape_character = args[:escape_character] if args.key?(:escape_character)
  @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter)
  @quote_character = args[:quote_character] if args.key?(:quote_character)
  @select_query = args[:select_query] if args.key?(:select_query)
end