Class: Google::Apis::AlloydbV1alpha::CsvImportOptions
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::CsvImportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Options for importing data in CSV format.
Instance Attribute Summary collapse
-
#columns ⇒ Array<String>
Optional.
-
#escape_character ⇒ String
Optional.
-
#field_delimiter ⇒ String
Optional.
-
#quote_character ⇒ String
Optional.
-
#table ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CsvImportOptions
constructor
A new instance of CsvImportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CsvImportOptions
Returns a new instance of CsvImportOptions.
1324 1325 1326 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<String>
Optional. The columns to which CSV data is imported. If not specified, all
columns of the database table are loaded with CSV data.
Corresponds to the JSON property columns
1296 1297 1298 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1296 def columns @columns end |
#escape_character ⇒ String
Optional. Specifies the character that should appear before a data character
that needs to be escaped. The default is same as quote character. The value of
this argument has to be a character in Hex ASCII Code.
Corresponds to the JSON property escapeCharacter
1303 1304 1305 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1303 def escape_character @escape_character end |
#field_delimiter ⇒ String
Optional. Specifies the character that separates columns within each row (line)
of the file. The default is comma. The value of this argument has to be a
character in Hex ASCII Code.
Corresponds to the JSON property fieldDelimiter
1310 1311 1312 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1310 def field_delimiter @field_delimiter end |
#quote_character ⇒ String
Optional. Specifies the quoting character to be used when a data value is
quoted. The default is double-quote. The value of this argument has to be a
character in Hex ASCII Code.
Corresponds to the JSON property quoteCharacter
1317 1318 1319 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1317 def quote_character @quote_character end |
#table ⇒ String
Required. The database table to import CSV file into.
Corresponds to the JSON property table
1322 1323 1324 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1322 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1329 1330 1331 1332 1333 1334 1335 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1329 def update!(**args) @columns = args[:columns] if args.key?(:columns) @escape_character = args[:escape_character] if args.key?(:escape_character) @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter) @quote_character = args[:quote_character] if args.key?(:quote_character) @table = args[:table] if args.key?(:table) end |