Class: Google::Apis::AlloydbV1alpha::GeminiClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Deprecated and unused. This message will be removed in the near future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeminiClusterConfig

Returns a new instance of GeminiClusterConfig.



1751
1752
1753
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitledBoolean Also known as: entitled?

Output only. Deprecated and unused. This field will be removed in the near future. Corresponds to the JSON property entitled

Returns:

  • (Boolean)


1748
1749
1750
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1748

def entitled
  @entitled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1756
1757
1758
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1756

def update!(**args)
  @entitled = args[:entitled] if args.key?(:entitled)
end