Class: Google::Apis::AlloydbV1alpha::GeminiInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Deprecated and unused. This message will be removed in the near future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeminiInstanceConfig

Returns a new instance of GeminiInstanceConfig.



1724
1725
1726
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitledBoolean Also known as: entitled?

Output only. Deprecated and unused. This field will be removed in the near future. Corresponds to the JSON property entitled

Returns:

  • (Boolean)


1721
1722
1723
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1721

def entitled
  @entitled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1729
1730
1731
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1729

def update!(**args)
  @entitled = args[:entitled] if args.key?(:entitled)
end