Class: Google::Apis::AlloydbV1alpha::GoogleCloudLocationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudLocationLocation

Returns a new instance of GoogleCloudLocationLocation.



1792
1793
1794
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


1767
1768
1769
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1767

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1773
1774
1775
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1773

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


1778
1779
1780
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1778

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


1784
1785
1786
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1784

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


1790
1791
1792
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1790

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1797
1798
1799
1800
1801
1802
1803
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1797

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end