Class: Google::Apis::AlloydbV1alpha::ImportClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Import cluster request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportClusterRequest

Returns a new instance of ImportClusterRequest.



1927
1928
1929
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_import_optionsGoogle::Apis::AlloydbV1alpha::CsvImportOptions

Options for importing data in CSV format. Corresponds to the JSON property csvImportOptions



1899
1900
1901
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1899

def csv_import_options
  @csv_import_options
end

#databaseString

Optional. Name of the database to which the import will be done. For import from SQL file, this is required only if the file does not specify a database. Note - Value provided should be the same as expected from SELECT current_database(); and NOT as a resource reference. Corresponds to the JSON property database

Returns:

  • (String)


1907
1908
1909
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1907

def database
  @database
end

#gcs_uriString

Required. The path to the file in Google Cloud Storage where the source file for import will be stored. The URI is in the form gs://bucketName/fileName. Corresponds to the JSON property gcsUri

Returns:

  • (String)


1913
1914
1915
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1913

def gcs_uri
  @gcs_uri
end

#sql_import_optionsGoogle::Apis::AlloydbV1alpha::SqlImportOptions

Options for importing data in SQL format. Corresponds to the JSON property sqlImportOptions



1918
1919
1920
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1918

def sql_import_options
  @sql_import_options
end

#userString

Optional. Database user to be used for importing the data. Note - Value provided should be the same as expected from SELECT current_user; and NOT as a resource reference. Corresponds to the JSON property user

Returns:

  • (String)


1925
1926
1927
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1925

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1932
1933
1934
1935
1936
1937
1938
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1932

def update!(**args)
  @csv_import_options = args[:csv_import_options] if args.key?(:csv_import_options)
  @database = args[:database] if args.key?(:database)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @sql_import_options = args[:sql_import_options] if args.key?(:sql_import_options)
  @user = args[:user] if args.key?(:user)
end