Class: Google::Apis::AlloydbV1alpha::IntegerRestrictions
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::IntegerRestrictions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Restrictions on INTEGER type values.
Instance Attribute Summary collapse
-
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
-
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntegerRestrictions
constructor
A new instance of IntegerRestrictions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntegerRestrictions
Returns a new instance of IntegerRestrictions.
2397 2398 2399 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
Corresponds to the JSON property maxValue
2390 2391 2392 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2390 def max_value @max_value end |
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Corresponds to the JSON property minValue
2395 2396 2397 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2395 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2402 2403 2404 2405 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2402 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |