Class: Google::Apis::AlloydbV1alpha::ListClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::ListClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Message for response to listing Clusters
Instance Attribute Summary collapse
-
#clusters ⇒ Array<Google::Apis::AlloydbV1alpha::Cluster>
The list of Cluster Corresponds to the JSON property
clusters. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClustersResponse
constructor
A new instance of ListClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClustersResponse
Returns a new instance of ListClustersResponse.
2427 2428 2429 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Array<Google::Apis::AlloydbV1alpha::Cluster>
The list of Cluster
Corresponds to the JSON property clusters
2415 2416 2417 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2415 def clusters @clusters end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2420 2421 2422 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2420 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2425 2426 2427 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2425 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2432 2433 2434 2435 2436 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2432 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |