Class: Google::Apis::AlloydbV1alpha::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::AlloydbV1alpha::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
2529 2530 2531 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
2514 2515 2516 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2514 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::AlloydbV1alpha::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
2519 2520 2521 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2519 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
2527 2528 2529 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2527 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2534 2535 2536 2537 2538 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2534 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |