Class: Google::Apis::AlloydbV1alpha::MaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

MaintenanceWindow specifies a preferred day and time for maintenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceWindow

Returns a new instance of MaintenanceWindow.



2736
2737
2738
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc. Corresponds to the JSON property day

Returns:

  • (String)


2727
2728
2729
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2727

def day
  @day
end

#start_timeGoogle::Apis::AlloydbV1alpha::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



2734
2735
2736
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2734

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2741
2742
2743
2744
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2741

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @start_time = args[:start_time] if args.key?(:start_time)
end