Class: Google::Apis::AlloydbV1alpha::NetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Metadata related to network configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkConfig

Returns a new instance of NetworkConfig.



2803
2804
2805
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_ip_rangeString

Optional. Name of the allocated IP range for the private IP AlloyDB cluster, for example: "google-managed-services-default". If set, the instance IPs for this cluster will be created in the allocated range. The range name must comply with RFC 1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. Field name is intended to be consistent with Cloud SQL. Corresponds to the JSON property allocatedIpRange

Returns:

  • (String)


2792
2793
2794
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2792

def allocated_ip_range
  @allocated_ip_range
end

#networkString

Optional. The resource link for the VPC network in which cluster resources are created and from which they are accessible via Private IP. The network must belong to the same project as the cluster. It is specified in the form: projects/project_number/global/networks/network_id`. This is required to create a cluster. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


2801
2802
2803
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2801

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2808
2809
2810
2811
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2808

def update!(**args)
  @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range)
  @network = args[:network] if args.key?(:network)
end