Class: Google::Apis::AlloydbV1alpha::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#upgrade_cluster_status ⇒ Google::Apis::AlloydbV1alpha::UpgradeClusterStatus
Message for current status of the Major Version Upgrade operation.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
3072 3073 3074 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
3031 3032 3033 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3031 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
3036 3037 3038 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3036 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
3041 3042 3043 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3041 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property requestedCancellation
3049 3050 3051 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3049 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
3055 3056 3057 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3055 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
3060 3061 3062 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3060 def target @target end |
#upgrade_cluster_status ⇒ Google::Apis::AlloydbV1alpha::UpgradeClusterStatus
Message for current status of the Major Version Upgrade operation.
Corresponds to the JSON property upgradeClusterStatus
3065 3066 3067 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3065 def upgrade_cluster_status @upgrade_cluster_status end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
3070 3071 3072 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3070 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3077 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @upgrade_cluster_status = args[:upgrade_cluster_status] if args.key?(:upgrade_cluster_status) @verb = args[:verb] if args.key?(:verb) end |