Class: Google::Apis::AlloydbV1alpha::PrimaryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Configuration for the primary cluster. It has the list of clusters that are replicating from this cluster. This should be set if and only if the cluster is of type PRIMARY.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrimaryConfig

Returns a new instance of PrimaryConfig.



3142
3143
3144
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secondary_cluster_namesArray<String>

Output only. Names of the clusters that are replicating from this cluster. Corresponds to the JSON property secondaryClusterNames

Returns:

  • (Array<String>)


3140
3141
3142
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3140

def secondary_cluster_names
  @secondary_cluster_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3147
3148
3149
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3147

def update!(**args)
  @secondary_cluster_names = args[:secondary_cluster_names] if args.key?(:secondary_cluster_names)
end