Class: Google::Apis::AlloydbV1alpha::PscInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::PscInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
PscInstanceConfig contains PSC related configuration at an instance level.
Instance Attribute Summary collapse
-
#allowed_consumer_projects ⇒ Array<String>
Optional.
-
#psc_auto_connection_policy_state ⇒ String
Optional.
-
#psc_auto_connections ⇒ Array<Google::Apis::AlloydbV1alpha::PscAutoConnectionConfig>
Optional.
-
#psc_auto_dns_state ⇒ String
Optional.
-
#psc_dns_name ⇒ String
Output only.
-
#psc_interface_configs ⇒ Array<Google::Apis::AlloydbV1alpha::PscInterfaceConfig>
Optional.
-
#service_attachment_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscInstanceConfig
constructor
A new instance of PscInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscInstanceConfig
Returns a new instance of PscInstanceConfig.
3319 3320 3321 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_consumer_projects ⇒ Array<String>
Optional. List of consumer projects that are allowed to create PSC endpoints
to service-attachments to this instance.
Corresponds to the JSON property allowedConsumerProjects
3282 3283 3284 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3282 def allowed_consumer_projects @allowed_consumer_projects end |
#psc_auto_connection_policy_state ⇒ String
Optional. Configuration for setting up PSC auto connection for the instance.
Corresponds to the JSON property pscAutoConnectionPolicyState
3287 3288 3289 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3287 def psc_auto_connection_policy_state @psc_auto_connection_policy_state end |
#psc_auto_connections ⇒ Array<Google::Apis::AlloydbV1alpha::PscAutoConnectionConfig>
Optional. Configurations for setting up PSC service automation.
Corresponds to the JSON property pscAutoConnections
3292 3293 3294 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3292 def psc_auto_connections @psc_auto_connections end |
#psc_auto_dns_state ⇒ String
Optional. Configuration for setting up PSC auto DNS for the instance.
Corresponds to the JSON property pscAutoDnsState
3297 3298 3299 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3297 def psc_auto_dns_state @psc_auto_dns_state end |
#psc_dns_name ⇒ String
Output only. The DNS name of the instance for PSC connectivity. Name
convention: ...alloydb-psc.goog
Corresponds to the JSON property pscDnsName
3303 3304 3305 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3303 def psc_dns_name @psc_dns_name end |
#psc_interface_configs ⇒ Array<Google::Apis::AlloydbV1alpha::PscInterfaceConfig>
Optional. Configurations for setting up PSC interfaces attached to the
instance which are used for outbound connectivity. Only primary instances can
have PSC interface attached. Currently we only support 0 or 1 PSC interface.
Corresponds to the JSON property pscInterfaceConfigs
3310 3311 3312 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3310 def psc_interface_configs @psc_interface_configs end |
#service_attachment_link ⇒ String
Output only. The service attachment created when Private Service Connect (PSC)
is enabled for the instance. The name of the resource will be in the format of
projects//regions//serviceAttachments/
Corresponds to the JSON property serviceAttachmentLink
3317 3318 3319 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3317 def @service_attachment_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3324 3325 3326 3327 3328 3329 3330 3331 3332 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3324 def update!(**args) @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects) @psc_auto_connection_policy_state = args[:psc_auto_connection_policy_state] if args.key?(:psc_auto_connection_policy_state) @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections) @psc_auto_dns_state = args[:psc_auto_dns_state] if args.key?(:psc_auto_dns_state) @psc_dns_name = args[:psc_dns_name] if args.key?(:psc_dns_name) @psc_interface_configs = args[:psc_interface_configs] if args.key?(:psc_interface_configs) @service_attachment_link = args[:service_attachment_link] if args.key?(:service_attachment_link) end |