Class: Google::Apis::AlloydbV1alpha::PscInstanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Information about the Private Service Connect (PSC) for the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscInstanceInfo

Returns a new instance of PscInstanceInfo.



3388
3389
3390
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3388

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_psc_auto_connection_policyBoolean Also known as: effective_psc_auto_connection_policy?

Output only. Indicates if the PSC auto connection policy is enabled for the instance. For older instances, this will be off by default, but for newer instances, this will be auto-enabled. Corresponds to the JSON property effectivePscAutoConnectionPolicy

Returns:

  • (Boolean)


3368
3369
3370
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3368

def effective_psc_auto_connection_policy
  @effective_psc_auto_connection_policy
end

#effective_psc_auto_dns_enabledBoolean Also known as: effective_psc_auto_dns_enabled?

Output only. The effective state of the PSC auto DNS for the instance. Corresponds to the JSON property effectivePscAutoDnsEnabled

Returns:

  • (Boolean)


3374
3375
3376
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3374

def effective_psc_auto_dns_enabled
  @effective_psc_auto_dns_enabled
end

#psc_auto_dns_namesArray<String>

Output only. Specifies the auto DNS names for the instance. Corresponds to the JSON property pscAutoDnsNames

Returns:

  • (Array<String>)


3380
3381
3382
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3380

def psc_auto_dns_names
  @psc_auto_dns_names
end

#service_connection_policyString

Output only. The PSC service connection policy name. The format is "projects// regions//serviceConnectionPolicies/" Corresponds to the JSON property serviceConnectionPolicy

Returns:

  • (String)


3386
3387
3388
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3386

def service_connection_policy
  @service_connection_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3393
3394
3395
3396
3397
3398
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3393

def update!(**args)
  @effective_psc_auto_connection_policy = args[:effective_psc_auto_connection_policy] if args.key?(:effective_psc_auto_connection_policy)
  @effective_psc_auto_dns_enabled = args[:effective_psc_auto_dns_enabled] if args.key?(:effective_psc_auto_dns_enabled)
  @psc_auto_dns_names = args[:psc_auto_dns_names] if args.key?(:psc_auto_dns_names)
  @service_connection_policy = args[:service_connection_policy] if args.key?(:service_connection_policy)
end