Class: Google::Apis::AlloydbV1alpha::PscInterfaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Configuration for setting up a PSC interface to enable outbound connectivity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscInterfaceConfig

Returns a new instance of PscInterfaceConfig.



3305
3306
3307
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_attachment_resourceString

The network attachment resource created in the consumer network to which the PSC interface will be linked. This is of the format: "projects/$ CONSUMER_PROJECT/regions/$REGION/networkAttachments/$ NETWORK_ATTACHMENT_NAME". The network attachment must be in the same region as the instance. Corresponds to the JSON property networkAttachmentResource

Returns:

  • (String)


3303
3304
3305
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3303

def network_attachment_resource
  @network_attachment_resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3310
3311
3312
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3310

def update!(**args)
  @network_attachment_resource = args[:network_attachment_resource] if args.key?(:network_attachment_resource)
end