Class: Google::Apis::AlloydbV1alpha::QuantityBasedExpiry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

A backup's position in a quantity-based retention queue, of backups with the same source cluster and type, with length, retention, specified by the backup' s retention policy. Once the position is greater than the retention, the backup is eligible to be garbage collected. Example: 5 backups from the same source cluster and type with a quantity-based retention of 3 and denoted by backup_id (position, retention). Safe: backup_5 (1, 3), backup_4, (2, 3), backup_3 (3, 3). Awaiting garbage collection: backup_2 (4, 3), backup_1 (5, 3)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuantityBasedExpiry

Returns a new instance of QuantityBasedExpiry.



3446
3447
3448
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retention_countFixnum

Output only. The backup's position among its backups with the same source cluster and type, by descending chronological order create time(i.e. newest first). Corresponds to the JSON property retentionCount

Returns:

  • (Fixnum)


3438
3439
3440
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3438

def retention_count
  @retention_count
end

#total_retention_countFixnum

Output only. The length of the quantity-based queue, specified by the backup's retention policy. Corresponds to the JSON property totalRetentionCount

Returns:

  • (Fixnum)


3444
3445
3446
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3444

def total_retention_count
  @total_retention_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3451
3452
3453
3454
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3451

def update!(**args)
  @retention_count = args[:retention_count] if args.key?(:retention_count)
  @total_retention_count = args[:total_retention_count] if args.key?(:total_retention_count)
end