Class: Google::Apis::AlloydbV1alpha::QuantityBasedRetention

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

A quantity based policy specifies that a certain number of the most recent successful backups should be retained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuantityBasedRetention

Returns a new instance of QuantityBasedRetention.



3365
3366
3367
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The number of backups to retain. Corresponds to the JSON property count

Returns:

  • (Fixnum)


3363
3364
3365
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3363

def count
  @count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3370
3371
3372
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3370

def update!(**args)
  @count = args[:count] if args.key?(:count)
end