Class: Google::Apis::AlloydbV1alpha::RestoreClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Message for restoring a Cluster from a backup or another cluster at a given point in time. NEXT_ID: 11

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreClusterRequest

Returns a new instance of RestoreClusterRequest.



3668
3669
3670
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_sourceGoogle::Apis::AlloydbV1alpha::BackupSource

Message describing a BackupSource. Corresponds to the JSON property backupSource



3617
3618
3619
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3617

def backup_source
  @backup_source
end

#backupdr_backup_sourceGoogle::Apis::AlloydbV1alpha::BackupDrBackupSource

Message describing a BackupDrBackupSource. Corresponds to the JSON property backupdrBackupSource



3622
3623
3624
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3622

def backupdr_backup_source
  @backupdr_backup_source
end

#backupdr_pitr_sourceGoogle::Apis::AlloydbV1alpha::BackupDrPitrSource

Message describing a BackupDrPitrSource. Corresponds to the JSON property backupdrPitrSource



3627
3628
3629
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3627

def backupdr_pitr_source
  @backupdr_pitr_source
end

#clusterGoogle::Apis::AlloydbV1alpha::Cluster

A cluster is a collection of regional AlloyDB resources. It can include a primary instance and one or more read pool instances. All cluster resources share a storage layer, which scales as needed. Corresponds to the JSON property cluster



3634
3635
3636
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3634

def cluster
  @cluster
end

#cluster_idString

Required. ID of the requesting object. Corresponds to the JSON property clusterId

Returns:

  • (String)


3639
3640
3641
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3639

def cluster_id
  @cluster_id
end

#continuous_backup_sourceGoogle::Apis::AlloydbV1alpha::ContinuousBackupSource

Message describing a ContinuousBackupSource. Corresponds to the JSON property continuousBackupSource



3644
3645
3646
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3644

def continuous_backup_source
  @continuous_backup_source
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3658
3659
3660
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3658

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


3665
3666
3667
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3665

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3673

def update!(**args)
  @backup_source = args[:backup_source] if args.key?(:backup_source)
  @backupdr_backup_source = args[:backupdr_backup_source] if args.key?(:backupdr_backup_source)
  @backupdr_pitr_source = args[:backupdr_pitr_source] if args.key?(:backupdr_pitr_source)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @continuous_backup_source = args[:continuous_backup_source] if args.key?(:continuous_backup_source)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end