Class: Google::Apis::AlloydbV1alpha::RestoreFromCloudSqlRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Message for registering Restoring from CloudSQL resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreFromCloudSqlRequest

Returns a new instance of RestoreFromCloudSqlRequest.



3682
3683
3684
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloudsql_backup_run_sourceGoogle::Apis::AlloydbV1alpha::CloudSqlBackupRunSource

The source CloudSQL backup resource. Corresponds to the JSON property cloudsqlBackupRunSource



3668
3669
3670
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3668

def cloudsql_backup_run_source
  @cloudsql_backup_run_source
end

#clusterGoogle::Apis::AlloydbV1alpha::Cluster

A cluster is a collection of regional AlloyDB resources. It can include a primary instance and one or more read pool instances. All cluster resources share a storage layer, which scales as needed. Corresponds to the JSON property cluster



3675
3676
3677
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3675

def cluster
  @cluster
end

#cluster_idString

Required. ID of the requesting object. Corresponds to the JSON property clusterId

Returns:

  • (String)


3680
3681
3682
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3680

def cluster_id
  @cluster_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3687
3688
3689
3690
3691
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3687

def update!(**args)
  @cloudsql_backup_run_source = args[:cloudsql_backup_run_source] if args.key?(:cloudsql_backup_run_source)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
end