Class: Google::Apis::AlloydbV1alpha::Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Upgrade stats for read pool instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stats

Returns a new instance of Stats.



3942
3943
3944
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFixnum

Number of read pool instances which failed to upgrade. Corresponds to the JSON property failed

Returns:

  • (Fixnum)


3925
3926
3927
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3925

def failed
  @failed
end

#not_startedFixnum

Number of read pool instances for which upgrade has not started. Corresponds to the JSON property notStarted

Returns:

  • (Fixnum)


3930
3931
3932
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3930

def not_started
  @not_started
end

#ongoingFixnum

Number of read pool instances undergoing upgrade. Corresponds to the JSON property ongoing

Returns:

  • (Fixnum)


3935
3936
3937
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3935

def ongoing
  @ongoing
end

#successFixnum

Number of read pool instances successfully upgraded. Corresponds to the JSON property success

Returns:

  • (Fixnum)


3940
3941
3942
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3940

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3947
3948
3949
3950
3951
3952
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3947

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @not_started = args[:not_started] if args.key?(:not_started)
  @ongoing = args[:ongoing] if args.key?(:ongoing)
  @success = args[:success] if args.key?(:success)
end