Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Configuration for availability of database instance

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration

Returns a new instance of StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration.



3948
3949
3950
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_failover_routing_configuredBoolean Also known as: automatic_failover_routing_configured?

Checks for existence of (multi-cluster) routing configuration that allows automatic failover to a different zone/region in case of an outage. Applicable to Bigtable resources. Corresponds to the JSON property automaticFailoverRoutingConfigured

Returns:

  • (Boolean)


3918
3919
3920
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3918

def automatic_failover_routing_configured
  @automatic_failover_routing_configured
end

#availability_typeString

Availability type. Potential values: * ZONAL: The instance serves data from only one zone. Outages in that zone affect data accessibility. * REGIONAL: The instance can serve data from more than one zone in a region (it is highly available). Corresponds to the JSON property availabilityType

Returns:

  • (String)


3927
3928
3929
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3927

def availability_type
  @availability_type
end

#cross_region_replica_configuredBoolean Also known as: cross_region_replica_configured?

Checks for resources that are configured to have redundancy, and ongoing replication across regions Corresponds to the JSON property crossRegionReplicaConfigured

Returns:

  • (Boolean)


3933
3934
3935
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3933

def cross_region_replica_configured
  @cross_region_replica_configured
end

#external_replica_configuredBoolean Also known as: external_replica_configured?

Corresponds to the JSON property externalReplicaConfigured

Returns:

  • (Boolean)


3939
3940
3941
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3939

def external_replica_configured
  @external_replica_configured
end

#promotable_replica_configuredBoolean Also known as: promotable_replica_configured?

Corresponds to the JSON property promotableReplicaConfigured

Returns:

  • (Boolean)


3945
3946
3947
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3945

def promotable_replica_configured
  @promotable_replica_configured
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3953
3954
3955
3956
3957
3958
3959
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3953

def update!(**args)
  @automatic_failover_routing_configured = args[:automatic_failover_routing_configured] if args.key?(:automatic_failover_routing_configured)
  @availability_type = args[:availability_type] if args.key?(:availability_type)
  @cross_region_replica_configured = args[:cross_region_replica_configured] if args.key?(:cross_region_replica_configured)
  @external_replica_configured = args[:external_replica_configured] if args.key?(:external_replica_configured)
  @promotable_replica_configured = args[:promotable_replica_configured] if args.key?(:promotable_replica_configured)
end