Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupDrMetadata.



4060
4061
4062
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



4032
4033
4034
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4032

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



4037
4038
4039
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4037

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



4043
4044
4045
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4043

def backupdr_configuration
  @backupdr_configuration
end

#full_resource_nameString

Required. Full resource name of this instance. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


4048
4049
4050
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4048

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time backup configuration was refreshed. Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4053

def last_refresh_time
  @last_refresh_time
end

#resource_idGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4058
4059
4060
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4058

def resource_id
  @resource_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4065
4066
4067
4068
4069
4070
4071
4072
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4065

def update!(**args)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
end