Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

DatabaseResourceId will serve as primary key for any resource ingestion event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceId.



4466
4467
4468
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#providerString

Required. Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged Corresponds to the JSON property provider

Returns:

  • (String)


4439
4440
4441
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4439

def provider
  @provider
end

#provider_descriptionString

Optional. Needs to be used only when the provider is PROVIDER_OTHER. Corresponds to the JSON property providerDescription

Returns:

  • (String)


4444
4445
4446
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4444

def provider_description
  @provider_description
end

#resource_typeString

Required. The type of resource this ID is identifying. Ex go/keep-sorted start alloydb.googleapis.com/Cluster, alloydb.googleapis.com/Instance, bigtableadmin. googleapis.com/Cluster, bigtableadmin.googleapis.com/Instance compute. googleapis.com/Instance firestore.googleapis.com/Database, memorystore. googleapis.com/Instance, redis.googleapis.com/Instance, redis.googleapis.com/ Cluster, oracledatabase.googleapis.com/CloudExadataInfrastructure oracledatabase.googleapis.com/CloudVmCluster oracledatabase.googleapis.com/ AutonomousDatabase spanner.googleapis.com/Instance, spanner.googleapis.com/ Database, sqladmin.googleapis.com/Instance, go/keep-sorted end REQUIRED Please refer go/condor-common-datamodel Corresponds to the JSON property resourceType

Returns:

  • (String)


4458
4459
4460
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4458

def resource_type
  @resource_type
end

#unique_idString

Required. A service-local token that distinguishes this resource from other resources within the same service. Corresponds to the JSON property uniqueId

Returns:

  • (String)


4464
4465
4466
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4464

def unique_id
  @unique_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4471
4472
4473
4474
4475
4476
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4471

def update!(**args)
  @provider = args[:provider] if args.key?(:provider)
  @provider_description = args[:provider_description] if args.key?(:provider_description)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
end