Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainUserLabels

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainUserLabels

Returns a new instance of StorageDatabasecenterPartnerapiV1mainUserLabels.



5398
5399
5400
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5396
5397
5398
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5396

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5403
5404
5405
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5403

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end