Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterProtoCommonProduct
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::StorageDatabasecenterProtoCommonProduct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Product specification for Condor resources.
Instance Attribute Summary collapse
-
#engine ⇒ String
The specific engine that the underlying database is running.
-
#minor_version ⇒ String
Minor version of the underlying database engine.
-
#type ⇒ String
Type of specific database product.
-
#version ⇒ String
Version of the underlying database engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterProtoCommonProduct
constructor
A new instance of StorageDatabasecenterProtoCommonProduct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterProtoCommonProduct
Returns a new instance of StorageDatabasecenterProtoCommonProduct.
5424 5425 5426 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#engine ⇒ String
The specific engine that the underlying database is running.
Corresponds to the JSON property engine
5404 5405 5406 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5404 def engine @engine end |
#minor_version ⇒ String
Minor version of the underlying database engine. Example values: For MySQL, it
could be "8.0.32", "5.7.32" etc.. For Postgres, it could be "14.3", "15.3" etc.
.
Corresponds to the JSON property minorVersion
5411 5412 5413 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5411 def minor_version @minor_version end |
#type ⇒ String
Type of specific database product. It could be CloudSQL, AlloyDB etc..
Corresponds to the JSON property type
5416 5417 5418 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5416 def type @type end |
#version ⇒ String
Version of the underlying database engine. Example values: For MySQL, it could
be "8.0", "5.7" etc.. For Postgres, it could be "14", "15" etc..
Corresponds to the JSON property version
5422 5423 5424 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5422 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5429 5430 5431 5432 5433 5434 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5429 def update!(**args) @engine = args[:engine] if args.key?(:engine) @minor_version = args[:minor_version] if args.key?(:minor_version) @type = args[:type] if args.key?(:type) @version = args[:version] if args.key?(:version) end |