Class: Google::Apis::AlloydbV1alpha::SupportedDatabaseFlag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

SupportedDatabaseFlag gives general information about a database flag, like type and allowed values. This is a static value that is defined on the server side, and it cannot be modified by callers. To set the Database flags on a particular Instance, a caller should modify the Instance.database_flags field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SupportedDatabaseFlag

Returns a new instance of SupportedDatabaseFlag.



5591
5592
5593
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accepts_multiple_valuesBoolean Also known as: accepts_multiple_values?

Whether the database flag accepts multiple values. If true, a comma-separated list of stringified values may be specified. Corresponds to the JSON property acceptsMultipleValues

Returns:

  • (Boolean)


5531
5532
5533
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5531

def accepts_multiple_values
  @accepts_multiple_values
end

#flag_nameString

The name of the database flag, e.g. "max_allowed_packets". The is a possibly key for the Instance.database_flags map field. Corresponds to the JSON property flagName

Returns:

  • (String)


5538
5539
5540
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5538

def flag_name
  @flag_name
end

#integer_restrictionsGoogle::Apis::AlloydbV1alpha::IntegerRestrictions

Restrictions on INTEGER type values. Corresponds to the JSON property integerRestrictions



5543
5544
5545
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5543

def integer_restrictions
  @integer_restrictions
end

#nameString

The name of the flag resource, following Google Cloud conventions, e.g.: * projects/project/locations/location/flags/flag This field currently has no semantic meaning. Corresponds to the JSON property name

Returns:

  • (String)


5550
5551
5552
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5550

def name
  @name
end

The recommended value for an INTEGER flag. Corresponds to the JSON property recommendedIntegerValue

Returns:

  • (Fixnum)


5555
5556
5557
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5555

def recommended_integer_value
  @recommended_integer_value
end

The recommended value for a STRING flag. Corresponds to the JSON property recommendedStringValue

Returns:

  • (String)


5560
5561
5562
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5560

def recommended_string_value
  @recommended_string_value
end

#requires_db_restartBoolean Also known as: requires_db_restart?

Whether setting or updating this flag on an Instance requires a database restart. If a flag that requires database restart is set, the backend will automatically restart the database (making sure to satisfy any availability SLO's). Corresponds to the JSON property requiresDbRestart

Returns:

  • (Boolean)


5568
5569
5570
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5568

def requires_db_restart
  @requires_db_restart
end

#scopeString

The scope of the flag. Corresponds to the JSON property scope

Returns:

  • (String)


5574
5575
5576
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5574

def scope
  @scope
end

#string_restrictionsGoogle::Apis::AlloydbV1alpha::StringRestrictions

Restrictions on STRING type values Corresponds to the JSON property stringRestrictions



5579
5580
5581
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5579

def string_restrictions
  @string_restrictions
end

#supported_db_versionsArray<String>

Major database engine versions for which this flag is supported. Corresponds to the JSON property supportedDbVersions

Returns:

  • (Array<String>)


5584
5585
5586
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5584

def supported_db_versions
  @supported_db_versions
end

#value_typeString

Corresponds to the JSON property valueType

Returns:

  • (String)


5589
5590
5591
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5589

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5596
5597
5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5596

def update!(**args)
  @accepts_multiple_values = args[:accepts_multiple_values] if args.key?(:accepts_multiple_values)
  @flag_name = args[:flag_name] if args.key?(:flag_name)
  @integer_restrictions = args[:integer_restrictions] if args.key?(:integer_restrictions)
  @name = args[:name] if args.key?(:name)
  @recommended_integer_value = args[:recommended_integer_value] if args.key?(:recommended_integer_value)
  @recommended_string_value = args[:recommended_string_value] if args.key?(:recommended_string_value)
  @requires_db_restart = args[:requires_db_restart] if args.key?(:requires_db_restart)
  @scope = args[:scope] if args.key?(:scope)
  @string_restrictions = args[:string_restrictions] if args.key?(:string_restrictions)
  @supported_db_versions = args[:supported_db_versions] if args.key?(:supported_db_versions)
  @value_type = args[:value_type] if args.key?(:value_type)
end