Class: Google::Apis::AlloydbV1alpha::TimeBasedRetention
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::TimeBasedRetention
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
A time based retention policy specifies that all backups within a certain time period should be retained.
Instance Attribute Summary collapse
-
#retention_period ⇒ String
The retention period.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeBasedRetention
constructor
A new instance of TimeBasedRetention.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeBasedRetention
Returns a new instance of TimeBasedRetention.
5645 5646 5647 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retention_period ⇒ String
The retention period.
Corresponds to the JSON property retentionPeriod
5643 5644 5645 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5643 def retention_period @retention_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5650 5651 5652 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5650 def update!(**args) @retention_period = args[:retention_period] if args.key?(:retention_period) end |