Class: Google::Apis::AlloydbV1alpha::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Message describing User object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



5898
5899
5900
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_rolesArray<String>

Optional. List of database roles this user has. The database role strings are subject to the PostgreSQL naming conventions. Corresponds to the JSON property databaseRoles

Returns:

  • (Array<String>)


5873
5874
5875
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5873

def database_roles
  @database_roles
end

#keep_extra_rolesBoolean Also known as: keep_extra_roles?

Input only. If the user already exists and it has additional roles, keep them granted. Corresponds to the JSON property keepExtraRoles

Returns:

  • (Boolean)


5879
5880
5881
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5879

def keep_extra_roles
  @keep_extra_roles
end

#nameString

Output only. Name of the resource in the form of projects/project/locations/ location/cluster/cluster/users/user. Corresponds to the JSON property name

Returns:

  • (String)


5886
5887
5888
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5886

def name
  @name
end

#passwordString

Input only. Password for the user. Corresponds to the JSON property password

Returns:

  • (String)


5891
5892
5893
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5891

def password
  @password
end

#user_typeString

Optional. Type of this user. Corresponds to the JSON property userType

Returns:

  • (String)


5896
5897
5898
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5896

def user_type
  @user_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5903
5904
5905
5906
5907
5908
5909
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5903

def update!(**args)
  @database_roles = args[:database_roles] if args.key?(:database_roles)
  @keep_extra_roles = args[:keep_extra_roles] if args.key?(:keep_extra_roles)
  @name = args[:name] if args.key?(:name)
  @password = args[:password] if args.key?(:password)
  @user_type = args[:user_type] if args.key?(:user_type)
end