Class: Google::Apis::AlloydbV1alpha::Backup
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::Backup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Message describing Backup object
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
-
#cluster_deleted ⇒ Boolean
(also: #cluster_deleted?)
Output only.
-
#cluster_name ⇒ String
Required.
-
#cluster_uid ⇒ String
Output only.
-
#create_completion_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#database_version ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#description ⇒ String
User-provided description of the backup.
-
#display_name ⇒ String
User-settable and human-readable display name for the Backup.
-
#encryption_config ⇒ Google::Apis::AlloydbV1alpha::EncryptionConfig
EncryptionConfig describes the encryption config of a cluster or a backup that is encrypted with a CMEK (customer-managed encryption key).
-
#encryption_info ⇒ Google::Apis::AlloydbV1alpha::EncryptionInfo
EncryptionInfo describes the encryption information of a cluster or a backup.
-
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154) Corresponds to the JSON property
etag. -
#expiry_quantity ⇒ Google::Apis::AlloydbV1alpha::QuantityBasedExpiry
A backup's position in a quantity-based retention queue, of backups with the same source cluster and type, with length, retention, specified by the backup' s retention policy.
-
#expiry_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs Corresponds to the JSON property
labels. -
#name ⇒ String
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#size_bytes ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#type ⇒ String
The backup type, which suggests the trigger for the backup.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Backup
constructor
A new instance of Backup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Backup
Returns a new instance of Backup.
314 315 316 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
This is distinct from labels. https://google.aip.dev/128
Corresponds to the JSON property annotations
155 156 157 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 155 def annotations @annotations end |
#cluster_deleted ⇒ Boolean Also known as: cluster_deleted?
Output only. Set to true if the cluster corresponding to this backup is
deleted. This field is only populated for when using the
BACKUP_VIEW_CLUSTER_DELETED view.
Corresponds to the JSON property clusterDeleted
162 163 164 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 162 def cluster_deleted @cluster_deleted end |
#cluster_name ⇒ String
Required. The full resource name of the backup source cluster (e.g., projects/
project/locations/region/clusters/cluster_id).
Corresponds to the JSON property clusterName
169 170 171 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 169 def cluster_name @cluster_name end |
#cluster_uid ⇒ String
Output only. The system-generated UID of the cluster which was used to create
this resource.
Corresponds to the JSON property clusterUid
175 176 177 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 175 def cluster_uid @cluster_uid end |
#create_completion_time ⇒ String
Output only. Timestamp when the resource finished being created.
Corresponds to the JSON property createCompletionTime
180 181 182 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 180 def create_completion_time @create_completion_time end |
#create_time ⇒ String
Output only. Create time stamp
Corresponds to the JSON property createTime
185 186 187 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 185 def create_time @create_time end |
#database_version ⇒ String
Output only. The database engine major version of the cluster this backup was
created from. Any restored cluster created from this backup will have the same
database version.
Corresponds to the JSON property databaseVersion
192 193 194 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 192 def database_version @database_version end |
#delete_time ⇒ String
Output only. Delete time stamp
Corresponds to the JSON property deleteTime
197 198 199 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 197 def delete_time @delete_time end |
#description ⇒ String
User-provided description of the backup.
Corresponds to the JSON property description
202 203 204 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 202 def description @description end |
#display_name ⇒ String
User-settable and human-readable display name for the Backup.
Corresponds to the JSON property displayName
207 208 209 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 207 def display_name @display_name end |
#encryption_config ⇒ Google::Apis::AlloydbV1alpha::EncryptionConfig
EncryptionConfig describes the encryption config of a cluster or a backup that
is encrypted with a CMEK (customer-managed encryption key).
Corresponds to the JSON property encryptionConfig
213 214 215 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 213 def encryption_config @encryption_config end |
#encryption_info ⇒ Google::Apis::AlloydbV1alpha::EncryptionInfo
EncryptionInfo describes the encryption information of a cluster or a backup.
Corresponds to the JSON property encryptionInfo
218 219 220 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 218 def encryption_info @encryption_info end |
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154)
Corresponds to the JSON property etag
223 224 225 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 223 def etag @etag end |
#expiry_quantity ⇒ Google::Apis::AlloydbV1alpha::QuantityBasedExpiry
A backup's position in a quantity-based retention queue, of backups with the
same source cluster and type, with length, retention, specified by the backup'
s retention policy. Once the position is greater than the retention, the
backup is eligible to be garbage collected. Example: 5 backups from the same
source cluster and type with a quantity-based retention of 3 and denoted by
backup_id (position, retention). Safe: backup_5 (1, 3), backup_4, (2, 3),
backup_3 (3, 3). Awaiting garbage collection: backup_2 (4, 3), backup_1 (5, 3)
Corresponds to the JSON property expiryQuantity
234 235 236 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 234 def expiry_quantity @expiry_quantity end |
#expiry_time ⇒ String
Output only. The time at which after the backup is eligible to be garbage
collected. It is the duration specified by the backup's retention policy,
added to the backup's create_time.
Corresponds to the JSON property expiryTime
241 242 243 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 241 def expiry_time @expiry_time end |
#labels ⇒ Hash<String,String>
Labels as key value pairs
Corresponds to the JSON property labels
246 247 248 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 246 def labels @labels end |
#name ⇒ String
Output only. The name of the backup resource with the format: * projects/
project/locations/region/backups/backup_id where the cluster and backup
ID segments should satisfy the regex expression [a-z]([a-z0-9-]0,61[a-z0-9])
?, e.g. 1-63 characters of lowercase letters, numbers, and dashes, starting
with a letter, and ending with a letter or number. For more details see https:/
/google.aip.dev/122. The prefix of the backup resource name is the name of the
parent resource: * projects/project/locations/region
Corresponds to the JSON property name
257 258 259 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 257 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Reconciling (https://google.aip.dev/128#reconciliation), if true,
indicates that the service is actively updating the resource. This can happen
due to user-triggered updates or system actions like failover or maintenance.
Corresponds to the JSON property reconciling
264 265 266 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 264 def reconciling @reconciling end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
270 271 272 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 270 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
276 277 278 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 276 def satisfies_pzs @satisfies_pzs end |
#size_bytes ⇒ Fixnum
Output only. The size of the backup in bytes.
Corresponds to the JSON property sizeBytes
282 283 284 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 282 def size_bytes @size_bytes end |
#state ⇒ String
Output only. The current state of the backup.
Corresponds to the JSON property state
287 288 289 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 287 def state @state end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
294 295 296 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 294 def @tags end |
#type ⇒ String
The backup type, which suggests the trigger for the backup.
Corresponds to the JSON property type
299 300 301 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 299 def type @type end |
#uid ⇒ String
Output only. The system-generated UID of the resource. The UID is assigned
when the resource is created, and it is retained until it is deleted.
Corresponds to the JSON property uid
305 306 307 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 305 def uid @uid end |
#update_time ⇒ String
Output only. Update time stamp Users should not infer any meaning from this
field. Its value is generally unrelated to the timing of the backup creation
operation.
Corresponds to the JSON property updateTime
312 313 314 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 312 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 319 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @cluster_deleted = args[:cluster_deleted] if args.key?(:cluster_deleted) @cluster_name = args[:cluster_name] if args.key?(:cluster_name) @cluster_uid = args[:cluster_uid] if args.key?(:cluster_uid) @create_completion_time = args[:create_completion_time] if args.key?(:create_completion_time) @create_time = args[:create_time] if args.key?(:create_time) @database_version = args[:database_version] if args.key?(:database_version) @delete_time = args[:delete_time] if args.key?(:delete_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @encryption_info = args[:encryption_info] if args.key?(:encryption_info) @etag = args[:etag] if args.key?(:etag) @expiry_quantity = args[:expiry_quantity] if args.key?(:expiry_quantity) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |