Class: Google::Apis::AlloydbV1alpha::BackupSource
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::BackupSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Message describing a BackupSource.
Instance Attribute Summary collapse
-
#backup_name ⇒ String
Required.
-
#backup_uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupSource
constructor
A new instance of BackupSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupSource
Returns a new instance of BackupSource.
517 518 519 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_name ⇒ String
Required. The name of the backup resource with the format: * projects/project
/locations/region/backups/backup_id
Corresponds to the JSON property backupName
508 509 510 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 508 def backup_name @backup_name end |
#backup_uid ⇒ String
Output only. The system-generated UID of the backup which was used to create
this resource. The UID is generated when the backup is created, and it is
retained until the backup is deleted.
Corresponds to the JSON property backupUid
515 516 517 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 515 def backup_uid @backup_uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
522 523 524 525 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 522 def update!(**args) @backup_name = args[:backup_name] if args.key?(:backup_name) @backup_uid = args[:backup_uid] if args.key?(:backup_uid) end |