Class: Google::Apis::AlloydbV1alpha::ClusterUpgradeDetails
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::ClusterUpgradeDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Upgrade details of a cluster. This cluster can be primary or secondary.
Instance Attribute Summary collapse
-
#cluster_type ⇒ String
Cluster type which can either be primary or secondary.
-
#database_version ⇒ String
Database version of the cluster after the upgrade operation.
-
#instance_upgrade_details ⇒ Array<Google::Apis::AlloydbV1alpha::InstanceUpgradeDetails>
Upgrade details of the instances directly associated with this cluster.
-
#name ⇒ String
Normalized name of the cluster Corresponds to the JSON property
name. -
#stage_info ⇒ Array<Google::Apis::AlloydbV1alpha::StageInfo>
Array containing stage info associated with this cluster.
-
#upgrade_status ⇒ String
Upgrade status of the cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterUpgradeDetails
constructor
A new instance of ClusterUpgradeDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterUpgradeDetails
Returns a new instance of ClusterUpgradeDetails.
988 989 990 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_type ⇒ String
Cluster type which can either be primary or secondary.
Corresponds to the JSON property clusterType
959 960 961 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 959 def cluster_type @cluster_type end |
#database_version ⇒ String
Database version of the cluster after the upgrade operation. This will be the
target version if the upgrade was successful otherwise it remains the same as
that before the upgrade operation.
Corresponds to the JSON property databaseVersion
966 967 968 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 966 def database_version @database_version end |
#instance_upgrade_details ⇒ Array<Google::Apis::AlloydbV1alpha::InstanceUpgradeDetails>
Upgrade details of the instances directly associated with this cluster.
Corresponds to the JSON property instanceUpgradeDetails
971 972 973 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 971 def instance_upgrade_details @instance_upgrade_details end |
#name ⇒ String
Normalized name of the cluster
Corresponds to the JSON property name
976 977 978 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 976 def name @name end |
#stage_info ⇒ Array<Google::Apis::AlloydbV1alpha::StageInfo>
Array containing stage info associated with this cluster.
Corresponds to the JSON property stageInfo
981 982 983 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 981 def stage_info @stage_info end |
#upgrade_status ⇒ String
Upgrade status of the cluster.
Corresponds to the JSON property upgradeStatus
986 987 988 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 986 def upgrade_status @upgrade_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
993 994 995 996 997 998 999 1000 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 993 def update!(**args) @cluster_type = args[:cluster_type] if args.key?(:cluster_type) @database_version = args[:database_version] if args.key?(:database_version) @instance_upgrade_details = args[:instance_upgrade_details] if args.key?(:instance_upgrade_details) @name = args[:name] if args.key?(:name) @stage_info = args[:stage_info] if args.key?(:stage_info) @upgrade_status = args[:upgrade_status] if args.key?(:upgrade_status) end |