Class: Google::Apis::AlloydbV1alpha::ClusterUpgradeDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Upgrade details of a cluster. This cluster can be primary or secondary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeDetails

Returns a new instance of ClusterUpgradeDetails.



987
988
989
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_typeString

Cluster type which can either be primary or secondary. Corresponds to the JSON property clusterType

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 958

def cluster_type
  @cluster_type
end

#database_versionString

Database version of the cluster after the upgrade operation. This will be the target version if the upgrade was successful otherwise it remains the same as that before the upgrade operation. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


965
966
967
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 965

def database_version
  @database_version
end

#instance_upgrade_detailsArray<Google::Apis::AlloydbV1alpha::InstanceUpgradeDetails>

Upgrade details of the instances directly associated with this cluster. Corresponds to the JSON property instanceUpgradeDetails



970
971
972
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 970

def instance_upgrade_details
  @instance_upgrade_details
end

#nameString

Normalized name of the cluster Corresponds to the JSON property name

Returns:

  • (String)


975
976
977
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 975

def name
  @name
end

#stage_infoArray<Google::Apis::AlloydbV1alpha::StageInfo>

Array containing stage info associated with this cluster. Corresponds to the JSON property stageInfo



980
981
982
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 980

def stage_info
  @stage_info
end

#upgrade_statusString

Upgrade status of the cluster. Corresponds to the JSON property upgradeStatus

Returns:

  • (String)


985
986
987
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 985

def upgrade_status
  @upgrade_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



992
993
994
995
996
997
998
999
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 992

def update!(**args)
  @cluster_type = args[:cluster_type] if args.key?(:cluster_type)
  @database_version = args[:database_version] if args.key?(:database_version)
  @instance_upgrade_details = args[:instance_upgrade_details] if args.key?(:instance_upgrade_details)
  @name = args[:name] if args.key?(:name)
  @stage_info = args[:stage_info] if args.key?(:stage_info)
  @upgrade_status = args[:upgrade_status] if args.key?(:upgrade_status)
end