Class: Google::Apis::AlloydbV1alpha::ConnectionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

ConnectionInfo singleton resource. https://google.aip.dev/156

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionInfo

Returns a new instance of ConnectionInfo.



1020
1021
1022
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_uidString

Output only. The unique ID of the Instance. Corresponds to the JSON property instanceUid

Returns:

  • (String)


986
987
988
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 986

def instance_uid
  @instance_uid
end

#ip_addressString

Output only. The private network IP address for the Instance. This is the default IP for the instance and is always created (even if enable_public_ip is set). This is the connection endpoint for an end-user application. Corresponds to the JSON property ipAddress

Returns:

  • (String)


993
994
995
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 993

def ip_address
  @ip_address
end

#nameString

The name of the ConnectionInfo singleton resource, e.g.: projects/project/ locations/location/clusters//instances//connectionInfo This field currently has no semantic meaning. Corresponds to the JSON property name

Returns:

  • (String)


1000
1001
1002
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1000

def name
  @name
end

#pem_certificate_chainArray<String>

Output only. The pem-encoded chain that may be used to verify the X.509 certificate. Expected to be in issuer-to-root order according to RFC 5246. Corresponds to the JSON property pemCertificateChain

Returns:

  • (Array<String>)


1006
1007
1008
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1006

def pem_certificate_chain
  @pem_certificate_chain
end

#psc_dns_nameString

Output only. The DNS name to use with PSC for the Instance. Corresponds to the JSON property pscDnsName

Returns:

  • (String)


1011
1012
1013
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1011

def psc_dns_name
  @psc_dns_name
end

#public_ip_addressString

Output only. The public IP addresses for the Instance. This is available ONLY when enable_public_ip is set. This is the connection endpoint for an end-user application. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


1018
1019
1020
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1018

def public_ip_address
  @public_ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1025
1026
1027
1028
1029
1030
1031
1032
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1025

def update!(**args)
  @instance_uid = args[:instance_uid] if args.key?(:instance_uid)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @name = args[:name] if args.key?(:name)
  @pem_certificate_chain = args[:pem_certificate_chain] if args.key?(:pem_certificate_chain)
  @psc_dns_name = args[:psc_dns_name] if args.key?(:psc_dns_name)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
end