Class: Google::Apis::AlloydbV1alpha::ContinuousBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

ContinuousBackupConfig describes the continuous backups recovery configurations of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContinuousBackupConfig

Returns a new instance of ContinuousBackupConfig.



1116
1117
1118
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Whether ContinuousBackup is enabled. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1100
1101
1102
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1100

def enabled
  @enabled
end

#encryption_configGoogle::Apis::AlloydbV1alpha::EncryptionConfig

EncryptionConfig describes the encryption config of a cluster or a backup that is encrypted with a CMEK (customer-managed encryption key). Corresponds to the JSON property encryptionConfig



1107
1108
1109
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1107

def encryption_config
  @encryption_config
end

#recovery_window_daysFixnum

The number of days that are eligible to restore from using PITR. To support the entire recovery window, backups and logs are retained for one day more than the recovery window. If not set, defaults to 14 days. Corresponds to the JSON property recoveryWindowDays

Returns:

  • (Fixnum)


1114
1115
1116
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1114

def recovery_window_days
  @recovery_window_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1121
1122
1123
1124
1125
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1121

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @recovery_window_days = args[:recovery_window_days] if args.key?(:recovery_window_days)
end