Class: Google::Apis::AlloydbV1alpha::ContinuousBackupSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Message describing a ContinuousBackupSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContinuousBackupSource

Returns a new instance of ContinuousBackupSource.



1172
1173
1174
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Required. The source cluster from which to restore. This cluster must have continuous backup enabled for this operation to succeed. For the required format, see the comment on the Cluster.name field. Corresponds to the JSON property cluster

Returns:

  • (String)


1165
1166
1167
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1165

def cluster
  @cluster
end

#point_in_timeString

Required. The point in time to restore to. Corresponds to the JSON property pointInTime

Returns:

  • (String)


1170
1171
1172
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1170

def point_in_time
  @point_in_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1177
1178
1179
1180
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1177

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @point_in_time = args[:point_in_time] if args.key?(:point_in_time)
end