Class: Google::Apis::AlloydbV1alpha::DataplexConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::DataplexConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Configuration for Dataplex integration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Dataplex is enabled by default for resources such as clusters and instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataplexConfig
constructor
A new instance of DataplexConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataplexConfig
Returns a new instance of DataplexConfig.
1353 1354 1355 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Dataplex is enabled by default for resources such as clusters and instances.
This flag controls the integration of AlloyDB PG resources (like databases,
schemas, and tables) with Dataplex."
Corresponds to the JSON property enabled
1350 1351 1352 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1350 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1358 1359 1360 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1358 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |