Class: Google::Apis::AlloydbV1alpha::Endpoint
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::Endpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Endpoint resource.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
User-settable and human-readable display name for the Endpoint.
-
#dns_config ⇒ Google::Apis::AlloydbV1alpha::DnsConfig
The DNS config for the endpoint, containing the DNS record name, type and targets.
-
#effective_target_instances ⇒ Array<String>
Output only.
-
#endpoint_type ⇒ String
The type of the endpoint, either write or read.
-
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154) Corresponds to the JSON property
etag. -
#name ⇒ String
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#target_instances ⇒ Array<String>
The names of the target instances for the endpoint, should be of format projects/
project/locations/region/clusters/cluster/instances/instance. -
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Endpoint
constructor
A new instance of Endpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Endpoint
Returns a new instance of Endpoint.
1553 1554 1555 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
This is distinct from labels. https://google.aip.dev/128
Corresponds to the JSON property annotations
1459 1460 1461 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1459 def annotations @annotations end |
#create_time ⇒ String
Output only. Create time stamp
Corresponds to the JSON property createTime
1464 1465 1466 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1464 def create_time @create_time end |
#delete_time ⇒ String
Output only. Delete time stamp
Corresponds to the JSON property deleteTime
1469 1470 1471 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1469 def delete_time @delete_time end |
#display_name ⇒ String
User-settable and human-readable display name for the Endpoint.
Corresponds to the JSON property displayName
1474 1475 1476 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1474 def display_name @display_name end |
#dns_config ⇒ Google::Apis::AlloydbV1alpha::DnsConfig
The DNS config for the endpoint, containing the DNS record name, type and
targets.
Corresponds to the JSON property dnsConfig
1480 1481 1482 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1480 def dns_config @dns_config end |
#effective_target_instances ⇒ Array<String>
Output only. The effective target instances that the endpoint is associated
with. This is a list of target instance names, e.g. projects/project_number/
locations/location/clusters/cluster_id/instances/instance_id For write
endpoint, there is only one effective target instance which has to be a
primary instance. Effective target instances are only different from target
instances after a switchover or cross-region failover operation. Otherwise,
effective_target_instances are the same as target_instances. Note that after a
cross-region failover operation, the effective_target_instances can be stale
until the operation to update the endpoint is complete.
Corresponds to the JSON property effectiveTargetInstances
1493 1494 1495 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1493 def effective_target_instances @effective_target_instances end |
#endpoint_type ⇒ String
The type of the endpoint, either write or read.
Corresponds to the JSON property endpointType
1498 1499 1500 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1498 def endpoint_type @endpoint_type end |
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154)
Corresponds to the JSON property etag
1503 1504 1505 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1503 def etag @etag end |
#name ⇒ String
Output only. Identifier. The name of the endpoint resource with the format: *
projects/project/locations/region/endpoints/endpoint_id where the
endpoint ID segment should satisfy the regex expression [a-z0-9-]+. For more
details see https://google.aip.dev/122. The prefix of the endpoint resource
name is the name of the parent resource: * projects/project/locations/
region
Corresponds to the JSON property name
1513 1514 1515 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1513 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Reconciling (https://google.aip.dev/128#reconciliation). Set to
true if the current state of Endpoint does not match the user's intended state,
and the service is actively updating the Endpoint to reconcile them. This can
happen due to user-triggered updates or system actions like failover or
maintenance.
Corresponds to the JSON property reconciling
1522 1523 1524 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1522 def reconciling @reconciling end |
#state ⇒ String
Output only. The state of the endpoint.
Corresponds to the JSON property state
1528 1529 1530 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1528 def state @state end |
#target_instances ⇒ Array<String>
The names of the target instances for the endpoint, should be of format
projects/project/locations/region/clusters/cluster/instances/instance.
For write endpoint, there is only one target instance which has to be a
primary instance. For read endpoint, there can be multiple target instances
which can be read or secondary instances. After a cross-region failover or
switchover operation, the endpoint will be associated with a different target
instance. This change will be reflected in the effective_target_instances
field.
Corresponds to the JSON property targetInstances
1540 1541 1542 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1540 def target_instances @target_instances end |
#uid ⇒ String
Output only. The system-generated UID of the resource. The UID is assigned
when the resource is created, and it is retained until it is deleted.
Corresponds to the JSON property uid
1546 1547 1548 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1546 def uid @uid end |
#update_time ⇒ String
Output only. Update time stamp
Corresponds to the JSON property updateTime
1551 1552 1553 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1551 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1558 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @dns_config = args[:dns_config] if args.key?(:dns_config) @effective_target_instances = args[:effective_target_instances] if args.key?(:effective_target_instances) @endpoint_type = args[:endpoint_type] if args.key?(:endpoint_type) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @target_instances = args[:target_instances] if args.key?(:target_instances) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |