Class: Google::Apis::AlloydbV1alpha::ExportClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Export cluster request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportClusterRequest

Returns a new instance of ExportClusterRequest.



1602
1603
1604
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_export_optionsGoogle::Apis::AlloydbV1alpha::CsvExportOptions

Options for exporting data in CSV format. Corresponds to the JSON property csvExportOptions



1583
1584
1585
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1583

def csv_export_options
  @csv_export_options
end

#databaseString

Required. Name of the database where the export command will be executed. Note

  • Value provided should be the same as expected from SELECT current_database() ; and NOT as a resource reference. Corresponds to the JSON property database

Returns:

  • (String)


1590
1591
1592
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1590

def database
  @database
end

#gcs_destinationGoogle::Apis::AlloydbV1alpha::GcsDestination

Destination for Export. Export will be done to cloud storage. Corresponds to the JSON property gcsDestination



1595
1596
1597
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1595

def gcs_destination
  @gcs_destination
end

#sql_export_optionsGoogle::Apis::AlloydbV1alpha::SqlExportOptions

Options for exporting data in SQL format. Corresponds to the JSON property sqlExportOptions



1600
1601
1602
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1600

def sql_export_options
  @sql_export_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1607
1608
1609
1610
1611
1612
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1607

def update!(**args)
  @csv_export_options = args[:csv_export_options] if args.key?(:csv_export_options)
  @database = args[:database] if args.key?(:database)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @sql_export_options = args[:sql_export_options] if args.key?(:sql_export_options)
end