Class: Google::Apis::AlloydbV1alpha::GeminiClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Deprecated and unused. This message will be removed in the near future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeminiClusterConfig

Returns a new instance of GeminiClusterConfig.



1703
1704
1705
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitledBoolean Also known as: entitled?

Output only. Deprecated and unused. This field will be removed in the near future. Corresponds to the JSON property entitled

Returns:

  • (Boolean)


1700
1701
1702
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1700

def entitled
  @entitled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1708
1709
1710
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1708

def update!(**args)
  @entitled = args[:entitled] if args.key?(:entitled)
end