Class: Google::Apis::AlloydbV1alpha::InjectFaultRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::InjectFaultRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Message for triggering fault injection on an instance
Instance Attribute Summary collapse
-
#fault_type ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InjectFaultRequest
constructor
A new instance of InjectFaultRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InjectFaultRequest
Returns a new instance of InjectFaultRequest.
1972 1973 1974 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fault_type ⇒ String
Required. The type of fault to be injected in an instance.
Corresponds to the JSON property faultType
1948 1949 1950 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1948 def fault_type @fault_type end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if the original
operation with the same request ID was received, and if so, ignores the second
request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
1962 1963 1964 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1962 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
1969 1970 1971 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1969 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1977 1978 1979 1980 1981 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1977 def update!(**args) @fault_type = args[:fault_type] if args.key?(:fault_type) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |