Class: Google::Apis::AlloydbV1alpha::Instance
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
An Instance is a computing unit that an end customer can connect to. It's the main unit of computing resources in AlloyDB.
Instance Attribute Summary collapse
-
#activation_policy ⇒ String
Optional.
-
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
-
#availability_type ⇒ String
Availability type of an Instance.
-
#client_connection_config ⇒ Google::Apis::AlloydbV1alpha::ClientConnectionConfig
Client connection configuration Corresponds to the JSON property
clientConnectionConfig. -
#connection_pool_config ⇒ Google::Apis::AlloydbV1alpha::ConnectionPoolConfig
Configuration for Managed Connection Pool (MCP).
-
#create_time ⇒ String
Output only.
-
#data_api_access ⇒ String
Optional.
-
#database_flags ⇒ Hash<String,String>
Database flags.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
User-settable and human-readable display name for the Instance.
-
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154) Corresponds to the JSON property
etag. -
#gca_config ⇒ Google::Apis::AlloydbV1alpha::GcaInstanceConfig
Instance level configuration parameters related to the Gemini Cloud Assist product.
-
#gce_zone ⇒ String
The Compute Engine zone that the instance should serve from, per https://cloud.
-
#gemini_config ⇒ Google::Apis::AlloydbV1alpha::GeminiInstanceConfig
Deprecated and unused.
-
#instance_type ⇒ String
Required.
-
#ip_address ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs Corresponds to the JSON property
labels. -
#machine_config ⇒ Google::Apis::AlloydbV1alpha::MachineConfig
MachineConfig describes the configuration of a machine.
-
#maintenance_version_name ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#network_config ⇒ Google::Apis::AlloydbV1alpha::InstanceNetworkConfig
Metadata related to instance-level network configuration.
-
#nodes ⇒ Array<Google::Apis::AlloydbV1alpha::Node>
Output only.
-
#observability_config ⇒ Google::Apis::AlloydbV1alpha::ObservabilityInstanceConfig
Observability Instance specific configuration.
-
#outbound_public_ip_addresses ⇒ Array<String>
Output only.
-
#psc_instance_config ⇒ Google::Apis::AlloydbV1alpha::PscInstanceConfig
PscInstanceConfig contains PSC related configuration at an instance level.
-
#public_ip_address ⇒ String
Output only.
-
#query_insights_config ⇒ Google::Apis::AlloydbV1alpha::QueryInsightsInstanceConfig
QueryInsights Instance specific configuration.
-
#read_pool_config ⇒ Google::Apis::AlloydbV1alpha::ReadPoolConfig
Configuration for a read pool instance.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_policy ⇒ Google::Apis::AlloydbV1alpha::UpdatePolicy
Policy to be used while updating the instance.
-
#update_time ⇒ String
Output only.
-
#writable_node ⇒ Google::Apis::AlloydbV1alpha::Node
Details of a single node in the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
2222 2223 2224 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2222 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_policy ⇒ String
Optional. Specifies whether an instance needs to spin up. Once the instance is
active, the activation policy can be updated to the NEVER to stop the
instance. Likewise, the activation policy can be updated to ALWAYS to start
the instance. There are restrictions around when an instance can/cannot be
activated (for example, a read pool instance should be stopped before stopping
primary etc.). Please refer to the API documentation for more details.
Corresponds to the JSON property activationPolicy
1997 1998 1999 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 1997 def activation_policy @activation_policy end |
#annotations ⇒ Hash<String,String>
Annotations to allow client tools to store small amount of arbitrary data.
This is distinct from labels. https://google.aip.dev/128
Corresponds to the JSON property annotations
2003 2004 2005 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2003 def annotations @annotations end |
#availability_type ⇒ String
Availability type of an Instance. If empty, defaults to REGIONAL for primary
instances. For read pools, availability_type is always UNSPECIFIED. Instances
in the read pools are evenly distributed across available zones within the
region (i.e. read pools with more than one node will have a node in at least
two zones).
Corresponds to the JSON property availabilityType
2012 2013 2014 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2012 def availability_type @availability_type end |
#client_connection_config ⇒ Google::Apis::AlloydbV1alpha::ClientConnectionConfig
Client connection configuration
Corresponds to the JSON property clientConnectionConfig
2017 2018 2019 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2017 def client_connection_config @client_connection_config end |
#connection_pool_config ⇒ Google::Apis::AlloydbV1alpha::ConnectionPoolConfig
Configuration for Managed Connection Pool (MCP).
Corresponds to the JSON property connectionPoolConfig
2022 2023 2024 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2022 def connection_pool_config @connection_pool_config end |
#create_time ⇒ String
Output only. Create time stamp
Corresponds to the JSON property createTime
2027 2028 2029 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2027 def create_time @create_time end |
#data_api_access ⇒ String
Optional. Controls whether the Data API is enabled for this instance. When
enabled, this allows authorized users to connect to the instance from the
public internet using the executeSql API, even for private IP instances. If
this is not specified, the data API is enabled by default for Google internal
services like AlloyDB Studio. Disable it explicitly to disallow Google
internal services as well.
Corresponds to the JSON property dataApiAccess
2037 2038 2039 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2037 def data_api_access @data_api_access end |
#database_flags ⇒ Hash<String,String>
Database flags. Set at the instance level. They are copied from the primary
instance on secondary instance creation. Flags that have restrictions default
to the value at primary instance on read instances during creation. Read
instances can set new flags or override existing flags that are relevant for
reads, for example, for enabling columnar cache on a read instance. Flags set
on read instance might or might not be present on the primary instance. This
is a list of "key": "value" pairs. "key": The name of the flag. These flags
are passed at instance setup time, so include both server options and system
variables for Postgres. Flags are specified with underscores, not hyphens. "
value": The value of the flag. Booleans are set to on for true and off
for false. This field must be omitted if the flag doesn't take a value.
Corresponds to the JSON property databaseFlags
2052 2053 2054 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2052 def database_flags @database_flags end |
#delete_time ⇒ String
Output only. Delete time stamp
Corresponds to the JSON property deleteTime
2057 2058 2059 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2057 def delete_time @delete_time end |
#display_name ⇒ String
User-settable and human-readable display name for the Instance.
Corresponds to the JSON property displayName
2062 2063 2064 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2062 def display_name @display_name end |
#etag ⇒ String
For Resource freshness validation (https://google.aip.dev/154)
Corresponds to the JSON property etag
2067 2068 2069 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2067 def etag @etag end |
#gca_config ⇒ Google::Apis::AlloydbV1alpha::GcaInstanceConfig
Instance level configuration parameters related to the Gemini Cloud Assist
product.
Corresponds to the JSON property gcaConfig
2073 2074 2075 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2073 def gca_config @gca_config end |
#gce_zone ⇒ String
The Compute Engine zone that the instance should serve from, per https://cloud.
google.com/compute/docs/regions-zones This can ONLY be specified for ZONAL
instances. If present for a REGIONAL instance, an error will be thrown. If
this is absent for a ZONAL instance, instance is created in a random zone with
available capacity.
Corresponds to the JSON property gceZone
2082 2083 2084 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2082 def gce_zone @gce_zone end |
#gemini_config ⇒ Google::Apis::AlloydbV1alpha::GeminiInstanceConfig
Deprecated and unused. This message will be removed in the near future.
Corresponds to the JSON property geminiConfig
2087 2088 2089 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2087 def gemini_config @gemini_config end |
#instance_type ⇒ String
Required. The type of the instance. Specified at creation time.
Corresponds to the JSON property instanceType
2092 2093 2094 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2092 def instance_type @instance_type end |
#ip_address ⇒ String
Output only. The IP address for the Instance. This is the connection endpoint
for an end-user application.
Corresponds to the JSON property ipAddress
2098 2099 2100 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2098 def ip_address @ip_address end |
#labels ⇒ Hash<String,String>
Labels as key value pairs
Corresponds to the JSON property labels
2103 2104 2105 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2103 def labels @labels end |
#machine_config ⇒ Google::Apis::AlloydbV1alpha::MachineConfig
MachineConfig describes the configuration of a machine.
Corresponds to the JSON property machineConfig
2108 2109 2110 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2108 def machine_config @machine_config end |
#maintenance_version_name ⇒ String
Output only. Maintenance version of the instance, for example: POSTGRES_15.
2025_07_15.04_00. Output only. Update this field via the parent cluster's
maintenance_version field(s).
Corresponds to the JSON property maintenanceVersionName
2115 2116 2117 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2115 def maintenance_version_name @maintenance_version_name end |
#name ⇒ String
Output only. The name of the instance resource with the format: * projects/
project/locations/region/clusters/cluster_id/instances/instance_id
where the cluster and instance ID segments should satisfy the regex expression
[a-z]([a-z0-9-]0,61[a-z0-9])?, e.g. 1-63 characters of lowercase letters,
numbers, and dashes, starting with a letter, and ending with a letter or
number. For more details see https://google.aip.dev/122. The prefix of the
instance resource name is the name of the parent resource: * projects/project
/locations/region/clusters/cluster_id
Corresponds to the JSON property name
2127 2128 2129 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2127 def name @name end |
#network_config ⇒ Google::Apis::AlloydbV1alpha::InstanceNetworkConfig
Metadata related to instance-level network configuration.
Corresponds to the JSON property networkConfig
2132 2133 2134 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2132 def network_config @network_config end |
#nodes ⇒ Array<Google::Apis::AlloydbV1alpha::Node>
Output only. List of available read-only VMs in this instance, including the
standby for a PRIMARY instance.
Corresponds to the JSON property nodes
2138 2139 2140 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2138 def nodes @nodes end |
#observability_config ⇒ Google::Apis::AlloydbV1alpha::ObservabilityInstanceConfig
Observability Instance specific configuration.
Corresponds to the JSON property observabilityConfig
2143 2144 2145 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2143 def observability_config @observability_config end |
#outbound_public_ip_addresses ⇒ Array<String>
Output only. All outbound public IP addresses configured for the instance.
Corresponds to the JSON property outboundPublicIpAddresses
2148 2149 2150 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2148 def outbound_public_ip_addresses @outbound_public_ip_addresses end |
#psc_instance_config ⇒ Google::Apis::AlloydbV1alpha::PscInstanceConfig
PscInstanceConfig contains PSC related configuration at an instance level.
Corresponds to the JSON property pscInstanceConfig
2153 2154 2155 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2153 def psc_instance_config @psc_instance_config end |
#public_ip_address ⇒ String
Output only. The public IP addresses for the Instance. This is available ONLY
when enable_public_ip is set. This is the connection endpoint for an end-user
application.
Corresponds to the JSON property publicIpAddress
2160 2161 2162 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2160 def public_ip_address @public_ip_address end |
#query_insights_config ⇒ Google::Apis::AlloydbV1alpha::QueryInsightsInstanceConfig
QueryInsights Instance specific configuration.
Corresponds to the JSON property queryInsightsConfig
2165 2166 2167 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2165 def query_insights_config @query_insights_config end |
#read_pool_config ⇒ Google::Apis::AlloydbV1alpha::ReadPoolConfig
Configuration for a read pool instance.
Corresponds to the JSON property readPoolConfig
2170 2171 2172 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2170 def read_pool_config @read_pool_config end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Reconciling (https://google.aip.dev/128#reconciliation). Set to
true if the current state of Instance does not match the user's intended state,
and the service is actively updating the resource to reconcile them. This can
happen due to user-triggered updates or system actions like failover or
maintenance.
Corresponds to the JSON property reconciling
2179 2180 2181 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2179 def reconciling @reconciling end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2185 2186 2187 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2185 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2191 2192 2193 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2191 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The current serving state of the instance.
Corresponds to the JSON property state
2197 2198 2199 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2197 def state @state end |
#uid ⇒ String
Output only. The system-generated UID of the resource. The UID is assigned
when the resource is created, and it is retained until it is deleted.
Corresponds to the JSON property uid
2203 2204 2205 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2203 def uid @uid end |
#update_policy ⇒ Google::Apis::AlloydbV1alpha::UpdatePolicy
Policy to be used while updating the instance.
Corresponds to the JSON property updatePolicy
2208 2209 2210 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2208 def update_policy @update_policy end |
#update_time ⇒ String
Output only. Update time stamp
Corresponds to the JSON property updateTime
2213 2214 2215 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2213 def update_time @update_time end |
#writable_node ⇒ Google::Apis::AlloydbV1alpha::Node
Details of a single node in the instance. Nodes in an AlloyDB instance are
ephemeral, they can change during update, failover, autohealing and resize
operations.
Corresponds to the JSON property writableNode
2220 2221 2222 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2220 def writable_node @writable_node end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2227 def update!(**args) @activation_policy = args[:activation_policy] if args.key?(:activation_policy) @annotations = args[:annotations] if args.key?(:annotations) @availability_type = args[:availability_type] if args.key?(:availability_type) @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config) @connection_pool_config = args[:connection_pool_config] if args.key?(:connection_pool_config) @create_time = args[:create_time] if args.key?(:create_time) @data_api_access = args[:data_api_access] if args.key?(:data_api_access) @database_flags = args[:database_flags] if args.key?(:database_flags) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @gca_config = args[:gca_config] if args.key?(:gca_config) @gce_zone = args[:gce_zone] if args.key?(:gce_zone) @gemini_config = args[:gemini_config] if args.key?(:gemini_config) @instance_type = args[:instance_type] if args.key?(:instance_type) @ip_address = args[:ip_address] if args.key?(:ip_address) @labels = args[:labels] if args.key?(:labels) @machine_config = args[:machine_config] if args.key?(:machine_config) @maintenance_version_name = args[:maintenance_version_name] if args.key?(:maintenance_version_name) @name = args[:name] if args.key?(:name) @network_config = args[:network_config] if args.key?(:network_config) @nodes = args[:nodes] if args.key?(:nodes) @observability_config = args[:observability_config] if args.key?(:observability_config) @outbound_public_ip_addresses = args[:outbound_public_ip_addresses] if args.key?(:outbound_public_ip_addresses) @psc_instance_config = args[:psc_instance_config] if args.key?(:psc_instance_config) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) @query_insights_config = args[:query_insights_config] if args.key?(:query_insights_config) @read_pool_config = args[:read_pool_config] if args.key?(:read_pool_config) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_policy = args[:update_policy] if args.key?(:update_policy) @update_time = args[:update_time] if args.key?(:update_time) @writable_node = args[:writable_node] if args.key?(:writable_node) end |