Class: Google::Apis::AlloydbV1alpha::InstanceNetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Metadata related to instance-level network configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceNetworkConfig

Returns a new instance of InstanceNetworkConfig.



2320
2321
2322
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_ip_range_overrideString

Optional. Name of the allocated IP range for the private IP AlloyDB instance, for example: "google-managed-services-default". If set, the instance IPs will be created from this allocated range and will override the IP range used by the parent cluster. The range name must comply with RFC 1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z?. Corresponds to the JSON property allocatedIpRangeOverride

Returns:

  • (String)


2292
2293
2294
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2292

def allocated_ip_range_override
  @allocated_ip_range_override
end

#authorized_external_networksArray<Google::Apis::AlloydbV1alpha::AuthorizedNetwork>

Optional. A list of external network authorized to access this instance. Corresponds to the JSON property authorizedExternalNetworks



2297
2298
2299
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2297

def authorized_external_networks
  @authorized_external_networks
end

#enable_outbound_public_ipBoolean Also known as: enable_outbound_public_ip?

Optional. Enabling an outbound public IP address to support a database server sending requests out into the internet. Corresponds to the JSON property enableOutboundPublicIp

Returns:

  • (Boolean)


2303
2304
2305
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2303

def enable_outbound_public_ip
  @enable_outbound_public_ip
end

#enable_public_ipBoolean Also known as: enable_public_ip?

Optional. Enabling public ip for the instance. Corresponds to the JSON property enablePublicIp

Returns:

  • (Boolean)


2309
2310
2311
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2309

def enable_public_ip
  @enable_public_ip
end

#networkString

Output only. The resource link for the VPC network in which instance resources are created and from which they are accessible via Private IP. This will be the same value as the parent cluster's network. It is specified in the form: // projects/project_number/global/networks/network_id`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


2318
2319
2320
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2318

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2325
2326
2327
2328
2329
2330
2331
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2325

def update!(**args)
  @allocated_ip_range_override = args[:allocated_ip_range_override] if args.key?(:allocated_ip_range_override)
  @authorized_external_networks = args[:authorized_external_networks] if args.key?(:authorized_external_networks)
  @enable_outbound_public_ip = args[:enable_outbound_public_ip] if args.key?(:enable_outbound_public_ip)
  @enable_public_ip = args[:enable_public_ip] if args.key?(:enable_public_ip)
  @network = args[:network] if args.key?(:network)
end