Class: Google::Apis::AlloydbV1alpha::IntegerRestrictions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Restrictions on INTEGER type values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntegerRestrictions

Returns a new instance of IntegerRestrictions.



2379
2380
2381
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_valueFixnum

The maximum value that can be specified, if applicable. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


2372
2373
2374
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2372

def max_value
  @max_value
end

#min_valueFixnum

The minimum value that can be specified, if applicable. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


2377
2378
2379
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2377

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2384
2385
2386
2387
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2384

def update!(**args)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end