Class: Google::Apis::AlloydbV1alpha::IntegerRestrictions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Restrictions on INTEGER type values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntegerRestrictions

Returns a new instance of IntegerRestrictions.



2366
2367
2368
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_valueFixnum

The maximum value that can be specified, if applicable. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


2359
2360
2361
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2359

def max_value
  @max_value
end

#min_valueFixnum

The minimum value that can be specified, if applicable. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


2364
2365
2366
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2364

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2371
2372
2373
2374
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2371

def update!(**args)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end