Class: Google::Apis::AlloydbV1alpha::IntegerRestrictions
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::IntegerRestrictions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Restrictions on INTEGER type values.
Instance Attribute Summary collapse
-
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
-
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntegerRestrictions
constructor
A new instance of IntegerRestrictions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntegerRestrictions
Returns a new instance of IntegerRestrictions.
2366 2367 2368 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2366 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
Corresponds to the JSON property maxValue
2359 2360 2361 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2359 def max_value @max_value end |
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Corresponds to the JSON property minValue
2364 2365 2366 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2364 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2371 2372 2373 2374 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2371 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |