Class: Google::Apis::AlloydbV1alpha::ListUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::ListUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Message for response to listing Users
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
-
#users ⇒ Array<Google::Apis::AlloydbV1alpha::User>
The list of User Corresponds to the JSON property
users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUsersResponse
constructor
A new instance of ListUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUsersResponse
Returns a new instance of ListUsersResponse.
2633 2634 2635 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2621 2622 2623 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2621 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2626 2627 2628 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2626 def unreachable @unreachable end |
#users ⇒ Array<Google::Apis::AlloydbV1alpha::User>
The list of User
Corresponds to the JSON property users
2631 2632 2633 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2631 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2638 2639 2640 2641 2642 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2638 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @users = args[:users] if args.key?(:users) end |