Class: Google::Apis::AlloydbV1alpha::NetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::NetworkConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Metadata related to network configuration.
Instance Attribute Summary collapse
-
#allocated_ip_range ⇒ String
Optional.
-
#network ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkConfig
constructor
A new instance of NetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkConfig
Returns a new instance of NetworkConfig.
2748 2749 2750 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_ip_range ⇒ String
Optional. Name of the allocated IP range for the private IP AlloyDB cluster,
for example: "google-managed-services-default". If set, the instance IPs for
this cluster will be created in the allocated range. The range name must
comply with RFC 1035. Specifically, the name must be 1-63 characters long and
match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. Field name is
intended to be consistent with Cloud SQL.
Corresponds to the JSON property allocatedIpRange
2737 2738 2739 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2737 def allocated_ip_range @allocated_ip_range end |
#network ⇒ String
Optional. The resource link for the VPC network in which cluster resources are
created and from which they are accessible via Private IP. The network must
belong to the same project as the cluster. It is specified in the form:
projects/project_number/global/networks/network_id`. This is required to
create a cluster.
Corresponds to the JSON propertynetwork`
2746 2747 2748 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2746 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2753 2754 2755 2756 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2753 def update!(**args) @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range) @network = args[:network] if args.key?(:network) end |