Class: Google::Apis::AlloydbV1alpha::Node

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Details of a single node in the instance. Nodes in an AlloyDB instance are ephemeral, they can change during update, failover, autohealing and resize operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Node

Returns a new instance of Node.



2801
2802
2803
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. The identifier of the VM e.g. "test-read-0601-407e52be-ms3l". Corresponds to the JSON property id

Returns:

  • (String)


2774
2775
2776
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2774

def id
  @id
end

#ipString

Output only. The private IP address of the VM e.g. "10.57.0.34". Corresponds to the JSON property ip

Returns:

  • (String)


2779
2780
2781
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2779

def ip
  @ip
end

#is_hot_standbyBoolean Also known as: is_hot_standby?

Output only. Indicates whether the node set up to be configured as a hot standby. Corresponds to the JSON property isHotStandby

Returns:

  • (Boolean)


2785
2786
2787
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2785

def is_hot_standby
  @is_hot_standby
end

#stateString

Output only. Determined by state of the compute VM and postgres-service health. Compute VM state can have values listed in https://cloud.google.com/compute/ docs/instances/instance-life-cycle and postgres-service health can have values: HEALTHY and UNHEALTHY. Corresponds to the JSON property state

Returns:

  • (String)


2794
2795
2796
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2794

def state
  @state
end

#zone_idString

Output only. The Compute Engine zone of the VM e.g. "us-central1-b". Corresponds to the JSON property zoneId

Returns:

  • (String)


2799
2800
2801
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2799

def zone_id
  @zone_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2806
2807
2808
2809
2810
2811
2812
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2806

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @ip = args[:ip] if args.key?(:ip)
  @is_hot_standby = args[:is_hot_standby] if args.key?(:is_hot_standby)
  @state = args[:state] if args.key?(:state)
  @zone_id = args[:zone_id] if args.key?(:zone_id)
end