Class: Google::Apis::AlloydbV1alpha::Node
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::Node
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Details of a single node in the instance. Nodes in an AlloyDB instance are ephemeral, they can change during update, failover, autohealing and resize operations.
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#ip ⇒ String
Output only.
-
#is_hot_standby ⇒ Boolean
(also: #is_hot_standby?)
Output only.
-
#state ⇒ String
Output only.
-
#zone_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Node
constructor
A new instance of Node.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Node
Returns a new instance of Node.
2795 2796 2797 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. The identifier of the VM e.g. "test-read-0601-407e52be-ms3l".
Corresponds to the JSON property id
2768 2769 2770 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2768 def id @id end |
#ip ⇒ String
Output only. The private IP address of the VM e.g. "10.57.0.34".
Corresponds to the JSON property ip
2773 2774 2775 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2773 def ip @ip end |
#is_hot_standby ⇒ Boolean Also known as: is_hot_standby?
Output only. Indicates whether the node set up to be configured as a hot
standby.
Corresponds to the JSON property isHotStandby
2779 2780 2781 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2779 def is_hot_standby @is_hot_standby end |
#state ⇒ String
Output only. Determined by state of the compute VM and postgres-service health.
Compute VM state can have values listed in https://cloud.google.com/compute/
docs/instances/instance-life-cycle and postgres-service health can have values:
HEALTHY and UNHEALTHY.
Corresponds to the JSON property state
2788 2789 2790 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2788 def state @state end |
#zone_id ⇒ String
Output only. The Compute Engine zone of the VM e.g. "us-central1-b".
Corresponds to the JSON property zoneId
2793 2794 2795 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2793 def zone_id @zone_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2800 2801 2802 2803 2804 2805 2806 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2800 def update!(**args) @id = args[:id] if args.key?(:id) @ip = args[:ip] if args.key?(:ip) @is_hot_standby = args[:is_hot_standby] if args.key?(:is_hot_standby) @state = args[:state] if args.key?(:state) @zone_id = args[:zone_id] if args.key?(:zone_id) end |