Class: Google::Apis::AlloydbV1alpha::ObservabilityInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::ObservabilityInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Observability Instance specific configuration.
Instance Attribute Summary collapse
-
#assistive_experiences_enabled ⇒ Boolean
(also: #assistive_experiences_enabled?)
Whether assistive experiences are enabled for this AlloyDB instance.
-
#enabled ⇒ Boolean
(also: #enabled?)
Observability feature status for an instance.
-
#max_query_string_length ⇒ Fixnum
Query string length.
-
#preserve_comments ⇒ Boolean
(also: #preserve_comments?)
Preserve comments in query string for an instance.
-
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all queries combined.
-
#record_application_tags ⇒ Boolean
(also: #record_application_tags?)
Record application tags for an instance.
-
#track_active_queries ⇒ Boolean
(also: #track_active_queries?)
Track actively running queries on the instance.
-
#track_active_query_plan ⇒ Boolean
(also: #track_active_query_plan?)
Indicates whether to track active query plans for an instance.
-
#track_client_address ⇒ Boolean
(also: #track_client_address?)
Track client address for an instance.
-
#track_wait_event_types ⇒ Boolean
(also: #track_wait_event_types?)
Output only.
-
#track_wait_events ⇒ Boolean
(also: #track_wait_events?)
Track wait events during query execution for an instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObservabilityInstanceConfig
constructor
A new instance of ObservabilityInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObservabilityInstanceConfig
Returns a new instance of ObservabilityInstanceConfig.
2901 2902 2903 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assistive_experiences_enabled ⇒ Boolean Also known as: assistive_experiences_enabled?
Whether assistive experiences are enabled for this AlloyDB instance.
Corresponds to the JSON property assistiveExperiencesEnabled
2829 2830 2831 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2829 def assistive_experiences_enabled @assistive_experiences_enabled end |
#enabled ⇒ Boolean Also known as: enabled?
Observability feature status for an instance. This flag is turned "off" by
default.
Corresponds to the JSON property enabled
2836 2837 2838 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2836 def enabled @enabled end |
#max_query_string_length ⇒ Fixnum
Query string length. The default value is 10k.
Corresponds to the JSON property maxQueryStringLength
2842 2843 2844 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2842 def max_query_string_length @max_query_string_length end |
#preserve_comments ⇒ Boolean Also known as: preserve_comments?
Preserve comments in query string for an instance. This flag is turned "off"
by default.
Corresponds to the JSON property preserveComments
2848 2849 2850 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2848 def preserve_comments @preserve_comments end |
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all
queries combined. The default value is 200. Any integer between 0 to 200 is
considered valid.
Corresponds to the JSON property queryPlansPerMinute
2856 2857 2858 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2856 def query_plans_per_minute @query_plans_per_minute end |
#record_application_tags ⇒ Boolean Also known as:
Record application tags for an instance. This flag is turned "off" by default.
Corresponds to the JSON property recordApplicationTags
2861 2862 2863 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2861 def @record_application_tags end |
#track_active_queries ⇒ Boolean Also known as: track_active_queries?
Track actively running queries on the instance. If not set, this flag is "off"
by default.
Corresponds to the JSON property trackActiveQueries
2868 2869 2870 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2868 def track_active_queries @track_active_queries end |
#track_active_query_plan ⇒ Boolean Also known as: track_active_query_plan?
Indicates whether to track active query plans for an instance. If not set, the
default value is "off". Can only be enabled if track_active_queries is enabled.
Corresponds to the JSON property trackActiveQueryPlan
2875 2876 2877 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2875 def track_active_query_plan @track_active_query_plan end |
#track_client_address ⇒ Boolean Also known as: track_client_address?
Track client address for an instance. If not set, default value is "off".
Corresponds to the JSON property trackClientAddress
2881 2882 2883 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2881 def track_client_address @track_client_address end |
#track_wait_event_types ⇒ Boolean Also known as: track_wait_event_types?
Output only. Track wait event types during query execution for an instance.
This flag is turned "on" by default but tracking is enabled only after
observability enabled flag is also turned on. This is read-only flag and only
modifiable by internal API.
Corresponds to the JSON property trackWaitEventTypes
2890 2891 2892 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2890 def track_wait_event_types @track_wait_event_types end |
#track_wait_events ⇒ Boolean Also known as: track_wait_events?
Track wait events during query execution for an instance. This flag is turned "
on" by default but tracking is enabled only after observability enabled flag
is also turned on.
Corresponds to the JSON property trackWaitEvents
2898 2899 2900 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2898 def track_wait_events @track_wait_events end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2906 def update!(**args) @assistive_experiences_enabled = args[:assistive_experiences_enabled] if args.key?(:assistive_experiences_enabled) @enabled = args[:enabled] if args.key?(:enabled) @max_query_string_length = args[:max_query_string_length] if args.key?(:max_query_string_length) @preserve_comments = args[:preserve_comments] if args.key?(:preserve_comments) @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute) @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags) @track_active_queries = args[:track_active_queries] if args.key?(:track_active_queries) @track_active_query_plan = args[:track_active_query_plan] if args.key?(:track_active_query_plan) @track_client_address = args[:track_client_address] if args.key?(:track_client_address) @track_wait_event_types = args[:track_wait_event_types] if args.key?(:track_wait_event_types) @track_wait_events = args[:track_wait_events] if args.key?(:track_wait_events) end |