Class: Google::Apis::AlloydbV1alpha::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



3031
3032
3033
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2990
2991
2992
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2990

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2995
2996
2997
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 2995

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


3000
3001
3002
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3000

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


3008
3009
3010
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3008

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


3014
3015
3016
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3014

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3019

def target
  @target
end

#upgrade_cluster_statusGoogle::Apis::AlloydbV1alpha::UpgradeClusterStatus

Message for current status of the Major Version Upgrade operation. Corresponds to the JSON property upgradeClusterStatus



3024
3025
3026
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3024

def upgrade_cluster_status
  @upgrade_cluster_status
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


3029
3030
3031
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3029

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3036

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @upgrade_cluster_status = args[:upgrade_cluster_status] if args.key?(:upgrade_cluster_status)
  @verb = args[:verb] if args.key?(:verb)
end