Class: Google::Apis::AlloydbV1alpha::PscAutoConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::PscAutoConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Configuration for setting up PSC service automation. Consumer projects in the configs will be allowlisted automatically for the instance.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
The consumer network for the PSC service automation, example: "projects/vpc- host-project/global/networks/default".
-
#consumer_network_status ⇒ String
Output only.
-
#consumer_project ⇒ String
The consumer project to which the PSC service automation endpoint will be created.
-
#ip_address ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscAutoConnectionConfig
constructor
A new instance of PscAutoConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscAutoConnectionConfig
Returns a new instance of PscAutoConnectionConfig.
3201 3202 3203 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
The consumer network for the PSC service automation, example: "projects/vpc-
host-project/global/networks/default". The consumer network might be hosted a
different project than the consumer project.
Corresponds to the JSON property consumerNetwork
3162 3163 3164 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3162 def consumer_network @consumer_network end |
#consumer_network_status ⇒ String
Output only. The status of the service connection policy. Possible values: "
STATE_UNSPECIFIED" - Default state, when Connection Map is created initially. "
VALID" - Set when policy and map configuration is valid, and their matching
can lead to allowing creation of PSC Connections subject to other constraints
like connections limit. "CONNECTION_POLICY_MISSING" - No Service Connection
Policy found for this network and Service Class "POLICY_LIMIT_REACHED" -
Service Connection Policy limit reached for this network and Service Class "
CONSUMER_INSTANCE_PROJECT_NOT_ALLOWLISTED" - The consumer instance project is
not in AllowedGoogleProducersResourceHierarchyLevels of the matching
ServiceConnectionPolicy.
Corresponds to the JSON property consumerNetworkStatus
3176 3177 3178 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3176 def consumer_network_status @consumer_network_status end |
#consumer_project ⇒ String
The consumer project to which the PSC service automation endpoint will be
created.
Corresponds to the JSON property consumerProject
3182 3183 3184 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3182 def consumer_project @consumer_project end |
#ip_address ⇒ String
Output only. The IP address of the PSC service automation endpoint.
Corresponds to the JSON property ipAddress
3187 3188 3189 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3187 def ip_address @ip_address end |
#status ⇒ String
Output only. The status of the PSC service automation connection. Possible
values: "STATE_UNSPECIFIED" - An invalid state as the default case. "ACTIVE" -
The connection has been created successfully. "FAILED" - The connection is not
functional since some resources on the connection fail to be created. "
CREATING" - The connection is being created. "DELETING" - The connection is
being deleted. "CREATE_REPAIRING" - The connection is being repaired to
complete creation. "DELETE_REPAIRING" - The connection is being repaired to
complete deletion.
Corresponds to the JSON property status
3199 3200 3201 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3199 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3206 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @consumer_network_status = args[:consumer_network_status] if args.key?(:consumer_network_status) @consumer_project = args[:consumer_project] if args.key?(:consumer_project) @ip_address = args[:ip_address] if args.key?(:ip_address) @status = args[:status] if args.key?(:status) end |