Class: Google::Apis::AlloydbV1alpha::PscInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

PscInstanceConfig contains PSC related configuration at an instance level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscInstanceConfig

Returns a new instance of PscInstanceConfig.



3278
3279
3280
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_consumer_projectsArray<String>

Optional. List of consumer projects that are allowed to create PSC endpoints to service-attachments to this instance. Corresponds to the JSON property allowedConsumerProjects

Returns:

  • (Array<String>)


3251
3252
3253
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3251

def allowed_consumer_projects
  @allowed_consumer_projects
end

#psc_auto_connectionsArray<Google::Apis::AlloydbV1alpha::PscAutoConnectionConfig>

Optional. Configurations for setting up PSC service automation. Corresponds to the JSON property pscAutoConnections



3256
3257
3258
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3256

def psc_auto_connections
  @psc_auto_connections
end

#psc_dns_nameString

Output only. The DNS name of the instance for PSC connectivity. Name convention: ...alloydb-psc.goog Corresponds to the JSON property pscDnsName

Returns:

  • (String)


3262
3263
3264
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3262

def psc_dns_name
  @psc_dns_name
end

#psc_interface_configsArray<Google::Apis::AlloydbV1alpha::PscInterfaceConfig>

Optional. Configurations for setting up PSC interfaces attached to the instance which are used for outbound connectivity. Only primary instances can have PSC interface attached. Currently we only support 0 or 1 PSC interface. Corresponds to the JSON property pscInterfaceConfigs



3269
3270
3271
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3269

def psc_interface_configs
  @psc_interface_configs
end

Output only. The service attachment created when Private Service Connect (PSC) is enabled for the instance. The name of the resource will be in the format of projects//regions//serviceAttachments/ Corresponds to the JSON property serviceAttachmentLink

Returns:

  • (String)


3276
3277
3278
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3276

def service_attachment_link
  @service_attachment_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3283
3284
3285
3286
3287
3288
3289
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3283

def update!(**args)
  @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects)
  @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections)
  @psc_dns_name = args[:psc_dns_name] if args.key?(:psc_dns_name)
  @psc_interface_configs = args[:psc_interface_configs] if args.key?(:psc_interface_configs)
  @service_attachment_link = args[:service_attachment_link] if args.key?(:service_attachment_link)
end