Class: Google::Apis::AlloydbV1alpha::QuantityBasedRetention

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

A quantity based policy specifies that a certain number of the most recent successful backups should be retained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuantityBasedRetention

Returns a new instance of QuantityBasedRetention.



3359
3360
3361
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The number of backups to retain. Corresponds to the JSON property count

Returns:

  • (Fixnum)


3357
3358
3359
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3357

def count
  @count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3364
3365
3366
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3364

def update!(**args)
  @count = args[:count] if args.key?(:count)
end