Class: Google::Apis::AlloydbV1alpha::RestartInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestartInstanceRequest

Returns a new instance of RestartInstanceRequest.



3488
3489
3490
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#node_idsArray<String>

Optional. Full name of the nodes as obtained from INSTANCE_VIEW_FULL to restart upon. Applicable only to read instances. Corresponds to the JSON property nodeIds

Returns:

  • (Array<String>)


3464
3465
3466
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3464

def node_ids
  @node_ids
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3478
3479
3480
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3478

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


3485
3486
3487
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3485

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3493
3494
3495
3496
3497
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3493

def update!(**args)
  @node_ids = args[:node_ids] if args.key?(:node_ids)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end