Class: Google::Apis::AlloydbV1alpha::SecondaryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Configuration information for the secondary cluster. This should be set if and only if the cluster is of type SECONDARY.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecondaryConfig

Returns a new instance of SecondaryConfig.



3678
3679
3680
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#primary_cluster_nameString

The name of the primary cluster name with the format: * projects/project/ locations/region/clusters/cluster_id Corresponds to the JSON property primaryClusterName

Returns:

  • (String)


3676
3677
3678
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3676

def primary_cluster_name
  @primary_cluster_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3683
3684
3685
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3683

def update!(**args)
  @primary_cluster_name = args[:primary_cluster_name] if args.key?(:primary_cluster_name)
end