Class: Google::Apis::AlloydbV1alpha::StageInfo
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::StageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Stage information for different stages in the upgrade process.
Instance Attribute Summary collapse
-
#logs_url ⇒ String
logs_url is the URL for the logs associated with a stage if that stage has logs.
-
#stage ⇒ String
The stage.
-
#status ⇒ String
Status of the stage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageInfo
constructor
A new instance of StageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageInfo
Returns a new instance of StageInfo.
3790 3791 3792 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logs_url ⇒ String
logs_url is the URL for the logs associated with a stage if that stage has
logs. Right now, only three stages have logs: ALLOYDB_PRECHECK,
PG_UPGRADE_CHECK, PRIMARY_INSTANCE_UPGRADE.
Corresponds to the JSON property logsUrl
3778 3779 3780 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3778 def logs_url @logs_url end |
#stage ⇒ String
The stage.
Corresponds to the JSON property stage
3783 3784 3785 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3783 def stage @stage end |
#status ⇒ String
Status of the stage.
Corresponds to the JSON property status
3788 3789 3790 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3788 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3795 3796 3797 3798 3799 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3795 def update!(**args) @logs_url = args[:logs_url] if args.key?(:logs_url) @stage = args[:stage] if args.key?(:stage) @status = args[:status] if args.key?(:status) end |