Class: Google::Apis::AlloydbV1alpha::Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Upgrade stats for read pool instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stats

Returns a new instance of Stats.



3882
3883
3884
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFixnum

Number of read pool instances which failed to upgrade. Corresponds to the JSON property failed

Returns:

  • (Fixnum)


3865
3866
3867
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3865

def failed
  @failed
end

#not_startedFixnum

Number of read pool instances for which upgrade has not started. Corresponds to the JSON property notStarted

Returns:

  • (Fixnum)


3870
3871
3872
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3870

def not_started
  @not_started
end

#ongoingFixnum

Number of read pool instances undergoing upgrade. Corresponds to the JSON property ongoing

Returns:

  • (Fixnum)


3875
3876
3877
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3875

def ongoing
  @ongoing
end

#successFixnum

Number of read pool instances successfully upgraded. Corresponds to the JSON property success

Returns:

  • (Fixnum)


3880
3881
3882
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3880

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3887
3888
3889
3890
3891
3892
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3887

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @not_started = args[:not_started] if args.key?(:not_started)
  @ongoing = args[:ongoing] if args.key?(:ongoing)
  @success = args[:success] if args.key?(:success)
end