Class: Google::Apis::AlloydbV1alpha::Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Upgrade stats for read pool instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stats

Returns a new instance of Stats.



3863
3864
3865
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFixnum

Number of read pool instances which failed to upgrade. Corresponds to the JSON property failed

Returns:

  • (Fixnum)


3846
3847
3848
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3846

def failed
  @failed
end

#not_startedFixnum

Number of read pool instances for which upgrade has not started. Corresponds to the JSON property notStarted

Returns:

  • (Fixnum)


3851
3852
3853
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3851

def not_started
  @not_started
end

#ongoingFixnum

Number of read pool instances undergoing upgrade. Corresponds to the JSON property ongoing

Returns:

  • (Fixnum)


3856
3857
3858
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3856

def ongoing
  @ongoing
end

#successFixnum

Number of read pool instances successfully upgraded. Corresponds to the JSON property success

Returns:

  • (Fixnum)


3861
3862
3863
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3861

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3868
3869
3870
3871
3872
3873
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3868

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @not_started = args[:not_started] if args.key?(:not_started)
  @ongoing = args[:ongoing] if args.key?(:ongoing)
  @success = args[:success] if args.key?(:success)
end