Class: Google::Apis::AlloydbV1alpha::Stats
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::Stats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Upgrade stats for read pool instances.
Instance Attribute Summary collapse
-
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
-
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
-
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
-
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stats
constructor
A new instance of Stats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stats
Returns a new instance of Stats.
3863 3864 3865 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
Corresponds to the JSON property failed
3846 3847 3848 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3846 def failed @failed end |
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
Corresponds to the JSON property notStarted
3851 3852 3853 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3851 def not_started @not_started end |
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
Corresponds to the JSON property ongoing
3856 3857 3858 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3856 def ongoing @ongoing end |
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Corresponds to the JSON property success
3861 3862 3863 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3861 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3868 3869 3870 3871 3872 3873 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 3868 def update!(**args) @failed = args[:failed] if args.key?(:failed) @not_started = args[:not_started] if args.key?(:not_started) @ongoing = args[:ongoing] if args.key?(:ongoing) @success = args[:success] if args.key?(:success) end |