Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.
Instance Attribute Summary collapse
-
#backup_configuration ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
-
#backupdr_configuration ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of database resource.
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainBackupDrMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupDrMetadata.
4054 4055 4056 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configuration ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
4026 4027 4028 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4026 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
Corresponds to the JSON property backupRun
4031 4032 4033 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4031 def backup_run @backup_run end |
#backupdr_configuration ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of
database resource.
Corresponds to the JSON property backupdrConfiguration
4037 4038 4039 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4037 def backupdr_configuration @backupdr_configuration end |
#full_resource_name ⇒ String
Required. Full resource name of this instance.
Corresponds to the JSON property fullResourceName
4042 4043 4044 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4042 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time backup configuration was refreshed.
Corresponds to the JSON property lastRefreshTime
4047 4048 4049 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4047 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
4052 4053 4054 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4052 def resource_id @resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4059 4060 4061 4062 4063 4064 4065 4066 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4059 def update!(**args) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) end |