Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainCompliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainCompliance

Returns a new instance of StorageDatabasecenterPartnerapiV1mainCompliance.



4121
4122
4123
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


4114
4115
4116
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4114

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


4119
4120
4121
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4119

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4126
4127
4128
4129
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4126

def update!(**args)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end