Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

DatabaseResourceFeed is the top level proto to be used to ingest different database resource level events into Condor platform. Next ID: 13

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed.



4283
4284
4285
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupdr_metadataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource. Corresponds to the JSON property backupdrMetadata



4222
4223
4224
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4222

def 
  @backupdr_metadata
end

#config_based_signal_dataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData

Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases. Corresponds to the JSON property configBasedSignalData



4229
4230
4231
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4229

def config_based_signal_data
  @config_based_signal_data
end

#database_resource_signal_dataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10 Corresponds to the JSON property databaseResourceSignalData



4236
4237
4238
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4236

def database_resource_signal_data
  @database_resource_signal_data
end

#feed_timestampString

Required. Timestamp when feed is generated. Corresponds to the JSON property feedTimestamp

Returns:

  • (String)


4241
4242
4243
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4241

def feed_timestamp
  @feed_timestamp
end

#feed_typeString

Required. Type feed to be ingested into condor Corresponds to the JSON property feedType

Returns:

  • (String)


4246
4247
4248
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4246

def feed_type
  @feed_type
end

#observability_metric_dataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainObservabilityMetricData

Corresponds to the JSON property observabilityMetricData



4251
4252
4253
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4251

def observability_metric_data
  @observability_metric_data
end

#recommendation_signal_dataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceRecommendationSignalData

Common model for database resource recommendation signal data. Corresponds to the JSON property recommendationSignalData



4256
4257
4258
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4256

def recommendation_signal_data
  @recommendation_signal_data
end

#resource_health_signal_dataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData

Common model for database resource health signal data. Corresponds to the JSON property resourceHealthSignalData



4261
4262
4263
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4261

def resource_health_signal_data
  @resource_health_signal_data
end

#resource_idGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4266
4267
4268
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4266

def resource_id
  @resource_id
end

#resource_metadataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata

Common model for database resource instance metadata. Next ID: 35 Corresponds to the JSON property resourceMetadata



4271
4272
4273
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4271

def 
  @resource_metadata
end

#skip_ingestionBoolean Also known as: skip_ingestion?

Optional. If true, the feed won't be ingested by DB Center. This indicates that the feed is intentionally skipped. For example, BackupDR feeds are only needed for resources integrated with DB Center (e.g., CloudSQL, AlloyDB). Feeds for non-integrated resources (e.g., Compute Engine, Persistent Disk) can be skipped. Corresponds to the JSON property skipIngestion

Returns:

  • (Boolean)


4280
4281
4282
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4280

def skip_ingestion
  @skip_ingestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4288

def update!(**args)
  @backupdr_metadata = args[:backupdr_metadata] if args.key?(:backupdr_metadata)
  @config_based_signal_data = args[:config_based_signal_data] if args.key?(:config_based_signal_data)
  @database_resource_signal_data = args[:database_resource_signal_data] if args.key?(:database_resource_signal_data)
  @feed_timestamp = args[:feed_timestamp] if args.key?(:feed_timestamp)
  @feed_type = args[:feed_type] if args.key?(:feed_type)
  @observability_metric_data = args[:observability_metric_data] if args.key?(:observability_metric_data)
  @recommendation_signal_data = args[:recommendation_signal_data] if args.key?(:recommendation_signal_data)
  @resource_health_signal_data = args[:resource_health_signal_data] if args.key?(:resource_health_signal_data)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_metadata = args[:resource_metadata] if args.key?(:resource_metadata)
  @skip_ingestion = args[:skip_ingestion] if args.key?(:skip_ingestion)
end