Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Common model for database resource health signal data.
Instance Attribute Summary collapse
-
#additional_metadata ⇒ Hash<String,Object>
Any other additional metadata Corresponds to the JSON property
additionalMetadata. -
#compliance ⇒ Array<Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainCompliance>
Industry standards associated with this signal; if this signal is an issue, that could be a violation of the associated industry standard(s).
-
#description ⇒ String
Description associated with signal Corresponds to the JSON property
description. -
#event_time ⇒ String
Required.
-
#external_uri ⇒ String
The external-uri of the signal, using which more information about this signal can be obtained.
-
#location ⇒ String
This is used to identify the location of the resource.
-
#name ⇒ String
Required.
-
#provider ⇒ String
Cloud provider name.
-
#resource_container ⇒ String
Closest parent container of this resource.
-
#resource_name ⇒ String
Required.
-
#signal_class ⇒ String
Required.
-
#signal_id ⇒ String
Required.
-
#signal_severity ⇒ String
The severity of the signal, such as if it's a HIGH or LOW severity.
-
#signal_type ⇒ String
Required.
-
#state ⇒ String
Corresponds to the JSON property
state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData.
4389 4390 4391 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_metadata ⇒ Hash<String,Object>
Any other additional metadata
Corresponds to the JSON property additionalMetadata
4303 4304 4305 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4303 def @additional_metadata end |
#compliance ⇒ Array<Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainCompliance>
Industry standards associated with this signal; if this signal is an issue,
that could be a violation of the associated industry standard(s). For example,
AUTO_BACKUP_DISABLED signal is associated with CIS GCP 1.1, CIS GCP 1.2, CIS
GCP 1.3, NIST 800-53 and ISO-27001 compliance standards. If a database
resource does not have automated backup enable, it will violate these
following industry standards.
Corresponds to the JSON property compliance
4313 4314 4315 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4313 def compliance @compliance end |
#description ⇒ String
Description associated with signal
Corresponds to the JSON property description
4318 4319 4320 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4318 def description @description end |
#event_time ⇒ String
Required. The last time at which the event described by this signal took place
Corresponds to the JSON property eventTime
4323 4324 4325 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4323 def event_time @event_time end |
#external_uri ⇒ String
The external-uri of the signal, using which more information about this signal
can be obtained. In GCP, this will take user to SCC page to get more details
about signals.
Corresponds to the JSON property externalUri
4330 4331 4332 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4330 def external_uri @external_uri end |
#location ⇒ String
This is used to identify the location of the resource. Example: "us-central1"
Corresponds to the JSON property location
4335 4336 4337 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4335 def location @location end |
#name ⇒ String
Required. The name of the signal, ex: PUBLIC_SQL_INSTANCE,
SQL_LOG_ERROR_VERBOSITY etc.
Corresponds to the JSON property name
4341 4342 4343 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4341 def name @name end |
#provider ⇒ String
Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged
Corresponds to the JSON property provider
4346 4347 4348 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4346 def provider @provider end |
#resource_container ⇒ String
Closest parent container of this resource. In GCP, 'container' refers to a
Cloud Resource Manager project. It must be resource name of a Cloud Resource
Manager project with the format of "provider//", such as "projects/123". For
GCP provided resources, number should be project number.
Corresponds to the JSON property resourceContainer
4354 4355 4356 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4354 def resource_container @resource_container end |
#resource_name ⇒ String
Required. Database resource name associated with the signal. Resource name to
follow CAIS resource_name format as noted here go/condor-common-datamodel
Corresponds to the JSON property resourceName
4360 4361 4362 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4360 def resource_name @resource_name end |
#signal_class ⇒ String
Required. The class of the signal, such as if it's a THREAT or VULNERABILITY.
Corresponds to the JSON property signalClass
4365 4366 4367 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4365 def signal_class @signal_class end |
#signal_id ⇒ String
Required. Unique identifier for the signal. This is an unique id which would
be mainatined by partner to identify a signal.
Corresponds to the JSON property signalId
4371 4372 4373 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4371 def signal_id @signal_id end |
#signal_severity ⇒ String
The severity of the signal, such as if it's a HIGH or LOW severity.
Corresponds to the JSON property signalSeverity
4376 4377 4378 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4376 def signal_severity @signal_severity end |
#signal_type ⇒ String
Required. Type of signal, for example, AVAILABLE_IN_MULTIPLE_ZONES,
LOGGING_MOST_ERRORS, etc.
Corresponds to the JSON property signalType
4382 4383 4384 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4382 def signal_type @signal_type end |
#state ⇒ String
Corresponds to the JSON property state
4387 4388 4389 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4387 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 4410 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4394 def update!(**args) @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata) @compliance = args[:compliance] if args.key?(:compliance) @description = args[:description] if args.key?(:description) @event_time = args[:event_time] if args.key?(:event_time) @external_uri = args[:external_uri] if args.key?(:external_uri) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @resource_container = args[:resource_container] if args.key?(:resource_container) @resource_name = args[:resource_name] if args.key?(:resource_name) @signal_class = args[:signal_class] if args.key?(:signal_class) @signal_id = args[:signal_id] if args.key?(:signal_id) @signal_severity = args[:signal_severity] if args.key?(:signal_severity) @signal_type = args[:signal_type] if args.key?(:signal_type) @state = args[:state] if args.key?(:state) end |