Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Common model for database resource instance metadata. Next ID: 35

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata.



4645
4646
4647
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_metadataHash<String,Object>

Field to ingest additional metadata whichd does not support proto format. Corresponds to the JSON property additionalMetadata

Returns:

  • (Hash<String,Object>)


4466
4467
4468
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4466

def 
  @additional_metadata
end

#availability_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration

Configuration for availability of database instance Corresponds to the JSON property availabilityConfiguration



4471
4472
4473
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4471

def availability_configuration
  @availability_configuration
end

#backup_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



4476
4477
4478
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4476

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



4481
4482
4483
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4481

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



4487
4488
4489
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4487

def backupdr_configuration
  @backupdr_configuration
end

#creation_timeString

The creation time of the resource, i.e. the time when resource is created and recorded in partner service. Corresponds to the JSON property creationTime

Returns:

  • (String)


4493
4494
4495
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4493

def creation_time
  @creation_time
end

#current_stateString

Current state of the instance. Corresponds to the JSON property currentState

Returns:

  • (String)


4498
4499
4500
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4498

def current_state
  @current_state
end

#custom_metadataGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainCustomMetadataData

Any custom metadata associated with the resource. e.g. A spanner instance can have multiple databases with its own unique metadata. Information for these individual databases can be captured in custom metadata data Corresponds to the JSON property customMetadata



4505
4506
4507
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4505

def 
  @custom_metadata
end

#editionString

Optional. Edition represents whether the instance is ENTERPRISE or ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to identify the edition of the instance. Corresponds to the JSON property edition

Returns:

  • (String)


4512
4513
4514
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4512

def edition
  @edition
end

#entitlementsArray<Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainEntitlement>

Entitlements associated with the resource Corresponds to the JSON property entitlements



4517
4518
4519
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4517

def entitlements
  @entitlements
end

#expected_stateString

The state that the instance is expected to be in. For example, an instance state can transition to UNHEALTHY due to wrong patch update, while the expected state will remain at the HEALTHY. Corresponds to the JSON property expectedState

Returns:

  • (String)


4524
4525
4526
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4524

def expected_state
  @expected_state
end

#gcbdr_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainGcbdrConfiguration

GCBDR Configuration for the resource. Corresponds to the JSON property gcbdrConfiguration



4529
4530
4531
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4529

def gcbdr_configuration
  @gcbdr_configuration
end

#idGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property id



4534
4535
4536
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4534

def id
  @id
end

#instance_typeString

The type of the instance. Specified at creation time. Corresponds to the JSON property instanceType

Returns:

  • (String)


4539
4540
4541
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4539

def instance_type
  @instance_type
end

#internal_additional_metadataHash<String,Object>

Field to ingest additional metadata which support proto format. Corresponds to the JSON property internalAdditionalMetadata

Returns:

  • (Hash<String,Object>)


4544
4545
4546
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4544

def 
  @internal_additional_metadata
end

#ip_addressGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainIpAddress

Used to send IP address information for a database resource. Corresponds to the JSON property ipAddress



4549
4550
4551
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4549

def ip_address
  @ip_address
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Optional. Whether deletion protection is enabled for this resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


4554
4555
4556
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4554

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#locationString

The resource location. REQUIRED Corresponds to the JSON property location

Returns:

  • (String)


4560
4561
4562
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4560

def location
  @location
end

#machine_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainMachineConfiguration

MachineConfiguration describes the configuration of a machine specific to Database Resource. Corresponds to the JSON property machineConfiguration



4566
4567
4568
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4566

def machine_configuration
  @machine_configuration
end

#maintenance_infoGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

MaintenanceInfo to capture the maintenance details of database resource. Corresponds to the JSON property maintenanceInfo



4571
4572
4573
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4571

def maintenance_info
  @maintenance_info
end

#modesArray<String>

Optional. The modes of the database resource. Corresponds to the JSON property modes

Returns:

  • (Array<String>)


4576
4577
4578
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4576

def modes
  @modes
end

#primary_resource_idGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property primaryResourceId



4581
4582
4583
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4581

def primary_resource_id
  @primary_resource_id
end

#primary_resource_locationString

Primary resource location. REQUIRED if the immediate parent exists when first time resource is getting ingested, otherwise optional. Corresponds to the JSON property primaryResourceLocation

Returns:

  • (String)


4587
4588
4589
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4587

def primary_resource_location
  @primary_resource_location
end

#productGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterProtoCommonProduct

Product specification for Condor resources. Corresponds to the JSON property product



4592
4593
4594
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4592

def product
  @product
end

#resource_containerString

Closest parent Cloud Resource Manager container of this resource. It must be resource name of a Cloud Resource Manager project with the format of "/", such as "projects/123". For GCP provided resources, number should be project number. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


4599
4600
4601
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4599

def resource_container
  @resource_container
end

#resource_flagsArray<Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceFlags>

Optional. List of resource flags for the database resource. Corresponds to the JSON property resourceFlags



4604
4605
4606
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4604

def resource_flags
  @resource_flags
end

#resource_nameString

Required. Different from DatabaseResourceId.unique_id, a resource name can be reused over time. That is, after a resource named "ABC" is deleted, the name " ABC" can be used to to create a new resource within the same source. Resource name to follow CAIS resource_name format as noted here go/condor-common- datamodel Corresponds to the JSON property resourceName

Returns:

  • (String)


4613
4614
4615
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4613

def resource_name
  @resource_name
end

#suspension_reasonString

Optional. Suspension reason for the resource. Corresponds to the JSON property suspensionReason

Returns:

  • (String)


4618
4619
4620
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4618

def suspension_reason
  @suspension_reason
end

#tags_setGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainTags

Message type for storing tags. Tags provide a way to create annotations for resources, and in some cases conditionally allow or deny policies based on whether a resource has a specific tag. Corresponds to the JSON property tagsSet



4625
4626
4627
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4625

def tags_set
  @tags_set
end

#updation_timeString

The time at which the resource was updated and recorded at partner service. Corresponds to the JSON property updationTime

Returns:

  • (String)


4630
4631
4632
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4630

def updation_time
  @updation_time
end

#user_label_setGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainUserLabels

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels. Corresponds to the JSON property userLabelSet



4637
4638
4639
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4637

def user_label_set
  @user_label_set
end

#zoneString

The resource zone. This is only applicable for zonal resources and will be empty for regional and multi-regional resources. Corresponds to the JSON property zone

Returns:

  • (String)


4643
4644
4645
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4643

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4650
4651
4652
4653
4654
4655
4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4650

def update!(**args)
  @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata)
  @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @current_state = args[:current_state] if args.key?(:current_state)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @edition = args[:edition] if args.key?(:edition)
  @entitlements = args[:entitlements] if args.key?(:entitlements)
  @expected_state = args[:expected_state] if args.key?(:expected_state)
  @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration)
  @id = args[:id] if args.key?(:id)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @internal_additional_metadata = args[:internal_additional_metadata] if args.key?(:internal_additional_metadata)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @location = args[:location] if args.key?(:location)
  @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration)
  @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info)
  @modes = args[:modes] if args.key?(:modes)
  @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id)
  @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location)
  @product = args[:product] if args.key?(:product)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @resource_flags = args[:resource_flags] if args.key?(:resource_flags)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason)
  @tags_set = args[:tags_set] if args.key?(:tags_set)
  @updation_time = args[:updation_time] if args.key?(:updation_time)
  @user_label_set = args[:user_label_set] if args.key?(:user_label_set)
  @zone = args[:zone] if args.key?(:zone)
end