Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainEntitlement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Proto representing the access that a user has to a specific feature/service. NextId: 3.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainEntitlement

Returns a new instance of StorageDatabasecenterPartnerapiV1mainEntitlement.



4821
4822
4823
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitlement_stateString

The current state of user's accessibility to a feature/benefit. Corresponds to the JSON property entitlementState

Returns:

  • (String)


4814
4815
4816
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4814

def entitlement_state
  @entitlement_state
end

#typeString

An enum that represents the type of this entitlement. Corresponds to the JSON property type

Returns:

  • (String)


4819
4820
4821
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4819

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4826
4827
4828
4829
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4826

def update!(**args)
  @entitlement_state = args[:entitlement_state] if args.key?(:entitlement_state)
  @type = args[:type] if args.key?(:type)
end