Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Metadata for individual internal resources in an instance. e.g. spanner instance can have multiple databases with unique configuration settings. Similarly bigtable can have multiple clusters within same bigtable instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata

Returns a new instance of StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata.



4890
4891
4892
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configurationGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



4861
4862
4863
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4861

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



4866
4867
4868
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4866

def backup_run
  @backup_run
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Whether deletion protection is enabled for this internal resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


4871
4872
4873
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4871

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#productGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterProtoCommonProduct

Product specification for Condor resources. Corresponds to the JSON property product



4877
4878
4879
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4877

def product
  @product
end

#resource_idGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4882
4883
4884
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4882

def resource_id
  @resource_id
end

#resource_nameString

Required. internal resource name for spanner this will be database name e.g." spanner.googleapis.com/projects/123/abc/instances/inst1/databases/db1" Corresponds to the JSON property resourceName

Returns:

  • (String)


4888
4889
4890
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4888

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4895
4896
4897
4898
4899
4900
4901
4902
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 4895

def update!(**args)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @product = args[:product] if args.key?(:product)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end