Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Disable validation warnings
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeTimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule
Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule.
5127 5128 5129 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5127 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
5106 5107 5108 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5106 def end_date @end_date end |
#start_date ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
5118 5119 5120 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5118 def start_date @start_date end |
#time ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeTimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
5125 5126 5127 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5125 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5132 5133 5134 5135 5136 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5132 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |