Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

MaintenanceInfo to capture the maintenance details of database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo.



5162
5163
5164
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_version_release_dateGoogle::Apis::AlloydbV1alpha::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property currentVersionReleaseDate



5123
5124
5125
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5123

def current_version_release_date
  @current_version_release_date
end

#deny_maintenance_schedulesArray<Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule>

Optional. List of Deny maintenance period for the database resource. Corresponds to the JSON property denyMaintenanceSchedules



5128
5129
5130
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5128

def deny_maintenance_schedules
  @deny_maintenance_schedules
end

#is_instance_stoppedBoolean Also known as: is_instance_stopped?

Optional. Whether the instance is in stopped state. This information is temporarily being captured in maintenanceInfo, till STOPPED state is supported by DB Center. Corresponds to the JSON property isInstanceStopped

Returns:

  • (Boolean)


5135
5136
5137
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5135

def is_instance_stopped
  @is_instance_stopped
end

#maintenance_scheduleGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule

Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. This is configured by the customer. Corresponds to the JSON property maintenanceSchedule



5143
5144
5145
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5143

def maintenance_schedule
  @maintenance_schedule
end

#maintenance_stateString

Output only. Current state of maintenance on the database resource. Corresponds to the JSON property maintenanceState

Returns:

  • (String)


5148
5149
5150
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5148

def maintenance_state
  @maintenance_state
end

#maintenance_versionString

Optional. Current Maintenance version of the database resource. Example: " MYSQL_8_0_41.R20250531.01_15" Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


5154
5155
5156
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5154

def maintenance_version
  @maintenance_version
end

#upcoming_maintenanceGoogle::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainUpcomingMaintenance

Upcoming maintenance for the database resource. This is generated by SLM once the upcoming maintenance schedule is published. Corresponds to the JSON property upcomingMaintenance



5160
5161
5162
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5160

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5167

def update!(**args)
  @current_version_release_date = args[:current_version_release_date] if args.key?(:current_version_release_date)
  @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules)
  @is_instance_stopped = args[:is_instance_stopped] if args.key?(:is_instance_stopped)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @maintenance_state = args[:maintenance_state] if args.key?(:maintenance_state)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end