Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. This is configured by the customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule

Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule.



5257
5258
5259
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Optional. Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc. Corresponds to the JSON property day

Returns:

  • (String)


5239
5240
5241
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5239

def day
  @day
end

#phaseString

Optional. Phase of the maintenance window. This is to capture order of maintenance. For example, for Cloud SQL resources, this can be used to capture if the maintenance window is in Week1, Week2, Week5, etc. Non production resources are usually part of early phase. For more details, refer to Cloud SQL resources - https://cloud.google.com/sql/docs/mysql/maintenance Corresponds to the JSON property phase

Returns:

  • (String)


5248
5249
5250
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5248

def phase
  @phase
end

#timeGoogle::Apis::AlloydbV1alpha::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property time



5255
5256
5257
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5255

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5262
5263
5264
5265
5266
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5262

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @phase = args[:phase] if args.key?(:phase)
  @time = args[:time] if args.key?(:time)
end