Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb
Overview
Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. This is configured by the customer.
Instance Attribute Summary collapse
-
#day ⇒ String
Optional.
-
#phase ⇒ String
Optional.
-
#time ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeTimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule
Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule.
5205 5206 5207 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Optional. Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc.
Corresponds to the JSON property day
5187 5188 5189 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5187 def day @day end |
#phase ⇒ String
Optional. Phase of the maintenance window. This is to capture order of
maintenance. For example, for Cloud SQL resources, this can be used to capture
if the maintenance window is in Week1, Week2, Week5, etc. Non production
resources are usually part of early phase. For more details, refer to Cloud
SQL resources - https://cloud.google.com/sql/docs/mysql/maintenance
Corresponds to the JSON property phase
5196 5197 5198 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5196 def phase @phase end |
#time ⇒ Google::Apis::AlloydbV1alpha::GoogleTypeTimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
5203 5204 5205 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5203 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5210 5211 5212 5213 5214 |
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5210 def update!(**args) @day = args[:day] if args.key?(:day) @phase = args[:phase] if args.key?(:phase) @time = args[:time] if args.key?(:time) end |