Class: Google::Apis::AlloydbV1alpha::StorageDatabasecenterPartnerapiV1mainUserLabels

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainUserLabels

Returns a new instance of StorageDatabasecenterPartnerapiV1mainUserLabels.



5346
5347
5348
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5344
5345
5346
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5344

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5351
5352
5353
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5351

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end