Class: Google::Apis::AlloydbV1alpha::UpgradeClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1alpha/classes.rb,
lib/google/apis/alloydb_v1alpha/representations.rb,
lib/google/apis/alloydb_v1alpha/representations.rb

Overview

Upgrades a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeClusterRequest

Returns a new instance of UpgradeClusterRequest.



5697
5698
5699
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5697

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The current etag of the Cluster. If an etag is provided and does not match the current etag of the Cluster, upgrade will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


5668
5669
5670
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5668

def etag
  @etag
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


5682
5683
5684
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5682

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


5689
5690
5691
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5689

def validate_only
  @validate_only
end

#versionString

Required. The version the cluster is going to be upgraded to. Corresponds to the JSON property version

Returns:

  • (String)


5695
5696
5697
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5695

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5702
5703
5704
5705
5706
5707
# File 'lib/google/apis/alloydb_v1alpha/classes.rb', line 5702

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
  @version = args[:version] if args.key?(:version)
end